import { AfterContentChecked, AfterViewChecked, AfterViewInit, Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { Router } from '@angular/router';
import { HttpService } from '../../../core/http.service';
import { Globals } from '../../../core/global';
import { SelectionModel } from '@angular/cdk/collections';
import { ModalService } from 'src/app/core/modal.service';
import { CdkDragDrop, moveItemInArray, transferArrayItem } from '@angular/cdk/drag-drop';
import { Subject } from 'rxjs';
import { debounceTime, distinctUntilChanged } from 'rxjs/operators';

@Component({
    selector: 'mega-menu',
    templateUrl: './mega-menu.component.html',
    styleUrls: ['./mega-menu.component.scss'],
})
export class MegaMenuComponent implements OnInit, AfterViewChecked {
    public menus: Array<any> = [];
    public menusDetail: Array<any> = [];
    public folderHeader: Array<any> = [];
    private folderHeaderOld: Array<any> = [];
    public filter: any = {};
    public menuFilter: string;

    @ViewChild("dialog") dialog: any
    @ViewChild("dialogDetail") dialogDetail: any
    @ViewChild("btnWrapper") btnWrapper: ElementRef;
    @ViewChild("btnContainer") btnContainer: ElementRef;

    selection = new SelectionModel<any>(true, []);
    public formDataD: any = {};
    public formDataH: any = {};
    public dataMenudetail: any;
    public dataMenuHeader: any;
    public selectMenuDetail: any = [];
    public selectMenuDetailOld: any = [];
    public dataMenuDetail: any;
    public dataHeader: any;
    public Mode: string = "";
    public dataHeadser: any;
    public FolderH_ID: any = '';
    public delData: any;
    public isEdit: boolean = false;
    public showScrollBtn: boolean = false;
    // private scrollPosition: number = 0;
    private scrollStep: number = 150;

    private oldContainerWidth: number;
    private showScrollChanged: Subject<boolean> = new Subject<boolean>();

    constructor(
        private router: Router,
        private global: Globals,
        private http: HttpService,
        private viewref: ViewContainerRef,
        private modal: ModalService,
    ) { 
        this.showScrollChanged
            .pipe(
                debounceTime(100),
                distinctUntilChanged()
            )
            .subscribe(v => {this.showScrollBtn = v})
    }

    ngOnInit(): void {
        this.GetSystemMenuList_ByUser();
        this.GetMenuDetailList();
    }

    ngAfterViewChecked() {
        let wrapperWidth = this.btnWrapper?.nativeElement.clientWidth;
        let containerWidth = this.btnContainer?.nativeElement.clientWidth;

        if(this.oldContainerWidth != containerWidth) {
            this.oldContainerWidth = containerWidth;

            if(wrapperWidth < containerWidth) {
                // this.showScrollBtn = true;
                this.showScrollChanged.next(true);
            } else {
                this.showScrollChanged.next(false);
            }
        }
    }

    GetSystemMenuList_ByUser() {
        this.http.get("System", "GetFolderMenu_ByUser")
            .subscribe(result => {
                this.menus = result;
                this.folderHeader = this.menus.filter((v, i, s) => this.global.findUnique(v, i, s, "ID"));
                this.folderHeaderOld = JSON.parse(JSON.stringify(this.folderHeader));
                // this.cd.markForCheck();
            })
    }

    MenusDetailFilter(menuFilter: string) {
        return this.menusDetail.filter((v) => (menuFilter ? v.MENU_NAME_EN.toUpperCase().indexOf(menuFilter.toString().toUpperCase()) : 0) >= 0);
    }

    MenuDetailFilter(headerId: number, menuFilter: string) {
        return this.menus.filter((v) => {
            return v.ID === headerId && (menuFilter ? v.MENU_NAME_EN.toUpperCase().indexOf(menuFilter.toString().toUpperCase()) : 0) >= 0
        });
    }

    FolderMenuDetailFilter() {
        if (this.menusDetail && this.selectMenuDetail) {
            return this.menusDetail.filter(menu => {
                return this.selectMenuDetail.findIndex(menuSelect => menuSelect.MENU_DETAIL_ID === menu.MENU_DETAIL_ID) === -1
                    && (menu.MENU_NAME_EN.toUpperCase().indexOf(this.filter.Unselected?.toUpperCase()) !== -1 || !this.filter.Unselected)
            })
        }

        return [];
    }

    SelectMenuDetailFilter() {
        return this.selectMenuDetail.filter(menu => {
            return menu.MENU_NAME_EN.toUpperCase().indexOf(this.filter.Selected?.toUpperCase()) !== -1 || !this.filter.Selected
        })
    }

    GetMenuDetailList() {
        this.http.get("System", "GetSystemMenuDetail")
            .subscribe(result => {
                this.menusDetail = result;
                // this.cd.markForCheck();
            })
    }

    GetFolderMenuDetailList(data: any) {
        this.http.get("System", "GetFolderDetail_ByID", data.ID)
            .subscribe(result => {
                this.selectMenuDetail = result;
                this.selectMenuDetailOld = JSON.parse(JSON.stringify(this.selectMenuDetail));
            })
    }

    AddHeader() {
        this.formDataH = {
            ID: 0,
            FOLDER_NO: this.folderHeader.length + 1,
            FOLDER_STATUS: "1",
        };
        this.dialog.title = "Add folder";
        this.dialog.OpenDialog();
        this.selectMenuDetail = [];
        this.filter = {};
    }

    SaveMenuHeader() {
        this.modal.confirm("Are you sure to save this change?", this.viewref, () => {
            this.http.post('System', 'SaveFolderHeader', JSON.stringify(this.formDataH))
                .subscribe(result => {
                    if (result) {
                        this.formDataH.ID = result[0].FOLDER_ID;
                        if (JSON.stringify(this.selectMenuDetail) !== JSON.stringify(this.selectMenuDetailOld)) {
                            this.SaveMenuDetail();
                        } else {
                            this.ngOnInit()
                            this.modal.info('Save successfully', this.viewref)
                            this.dialog.Close();
                        }
                    }
                }, (err) => {
                    this.modal.info('Error SaveMenuHeader', this.viewref)
                    console.log(err, 'err')
                })
        }, () => { })
    }

    SaveMenuHeaderOrder() {
        this.http.post('System', 'SaveFolderHeaderOrder', this.folderHeader)
            .subscribe(result => {
                if (result) {
                    this.GetSystemMenuList_ByUser()
                    this.modal.info('Save successfully', this.viewref)
                    this.isEdit = false;
                }
            }, (err) => {
                this.modal.info('Error SaveFolderHeaderOrder', this.viewref)
                console.log(err, 'err')
            })
    }

    DeleteMenuHeader() {
        this.modal.confirm("Are you sure to delete this folder?", this.viewref, () => {
            this.http.post('System', ['DeleteFolder', this.formDataH.ID], null)
                .subscribe(result => {
                    if (result) {
                        this.ngOnInit();
                        this.dialog.Close();
                    }
                })
        });
    }

    EditData(data: any) {
        this.filter = {};
        this.http.get("System", "GetFolderHeader_ByID", data.ID)
            .subscribe(result => {
                this.formDataH = result.length > 0 ? result[0] : [];
                this.GetSystemMenuList_ByUser();
                this.dialog.title = "Edit " + this.formDataH.FOLDER_NAME;
                this.dialog.OpenDialog();
            })
    }

    SaveMenuDetail() {
        this.FolderH_ID = this.formDataH.ID
        this.http.post('System', ['SaveFolderDetail', this.FolderH_ID], this.selectMenuDetail)
            .subscribe(result => {
                if (result) {
                    this.ngOnInit()
                    this.modal.info('Save successfully', this.viewref)
                    this.dialog.Close();
                }
            }, (err) => {

                this.modal.info('Error SaveMenuDetail', this.viewref)
                console.log(err, 'err')
            })
    }

    GoToPage(menu: any) {
        this.router.navigate(['/', menu.ROUTE_CONTROLLER_NAME, menu.ROUTE_VIEW_NAME]);
    }

    CloseEdit() {
        if (this.ShowSaveHeaderButton()) {
            this.modal.confirm("Any change will not be saved. Do you want to close edit mode?", this.viewref
                , () => {
                    this.ngOnInit();
                    this.isEdit = false;
                }, () => {
                    return false;
                })
        } else {
            this.isEdit = false;
        }
    }

    FolderDrop(event: CdkDragDrop<any>) {
        moveItemInArray(this.folderHeader, event.previousIndex, event.currentIndex);
    }

    DetailDrop(event: CdkDragDrop<any>) {
        if (event.previousContainer === event.container) {
            moveItemInArray(event.container.data, event.previousIndex, event.currentIndex);
        } else {
            transferArrayItem(event.previousContainer.data,
                event.container.data,
                event.previousIndex,
                event.currentIndex);
        }
    }

    ClearDetail() {
        this.modal.confirm("Are you sure to remove all menu from the list?", this.viewref
            , () => {
                this.selectMenuDetail = [];
            }, () => { })
    }

    ShowSaveHeaderButton() {
        return JSON.stringify(this.folderHeader) !== JSON.stringify(this.folderHeaderOld);
    }

    GoToReport() {
        this.global.GoToReport("PMS_RPT_IC_SNSD172_F", { P_YEAR: "2020", P_MONTH: "01" })
    }

    CheckActiveMenu(menu) {
        return this.router.url === "/".concat(menu.ROUTE_CONTROLLER_NAME, "/", menu.ROUTE_VIEW_NAME);
    }

    ScrollToLeft() {
        let currentScroll = this.btnWrapper?.nativeElement.scrollLeft;
        let nextScroll = Math.max(0, currentScroll - this.scrollStep);

        this.btnWrapper.nativeElement.scrollTo(nextScroll, 0);
    }

    ScrollToRight() {
        let wrapperWidth = this.btnWrapper?.nativeElement.clientWidth;
        let containerWidth = this.btnContainer?.nativeElement.clientWidth;
        let margin = 51
        let maxScroll = containerWidth - wrapperWidth + margin;
        let currentScroll = this.btnWrapper?.nativeElement.scrollLeft;
        let nextScroll = Math.min(currentScroll + this.scrollStep, maxScroll);

        this.btnWrapper.nativeElement.scrollTo(nextScroll, 0);
        
    }
}
