import { Component, OnInit, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { SelectionModel } from '@angular/cdk/collections';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';

@Component({
    selector: 'nsie002',
    templateUrl: './SNIE002.component.html',
    styleUrls: ['./SNIE002.component.css']
})

export class SNIE002Component implements OnInit {


    constructor(
        private http: HttpService,
        private router: Router,
        private modal : ModalService,
        private viewref : ViewContainerRef,
        private global : Globals
    ) { }

    public currentDate: string;
    public CustomerList: any;
    public tableData: any = [];
    public Searched : boolean = false;
    public Saved : boolean = false;

    public ConfigPart: any = {
        ColName: "LOOKUP_PART_NAME",
        ColValue: "",
        PlaceholderText: "Select Part No.",
        SourceController: "wPMS",
        SourceMethodName: "GetPartNo",
        NoOfShowRecords: 50,
        MinLengthSearch: 5
      }

      public ConfigDocType: any = {
        ColName: "LOOK_UP",
        ColValue: "",
        PlaceholderText: "Select Document Type",
        SourceController: "AC",
        SourceMethodName: "SNIE002_GET_DOCUMENT_TYPE",
        NoOfShowRecords: 50,
        MinLengthSearch: 0,
        UpperCase: true
      }

      public Params = {
          DOCUMENT_TYPE : null,
          DOC_NAME : null,
          PART_NO : null,
          PART_NAME : null,
          REVERSE_DOC_TYPE : null
      }

      public ParamsData = {
        LockMsLabel : "Q'ty",
        LockMsQty : 0,
        TotalNetQty : 0,
        TotalReverseQty : 0,
        StockMsQty : 0,
        DocNoFrom : null,
        DocNoTo : null,
        UpdateBy : null,
        UpdateDate : null,
        AverageCost: 0
      }
      public selection = new SelectionModel<any>(true, []);
      public DOCUMENT_DATE : any  = null  ;


      public tblFooterDetail: any = [
        {
          fieldName: "REVERSE_QTY",
          
          show: true
        }, 
        {
          fieldName: "NET_QTY",
          
          show: true
        },
        {
          fieldName: "REF_DOC",
          value: "",
          show: true
        },
        {
          fieldName : "REVERSE_QTY",
          value : 0,
          show : true
        }]

    ngOnInit() {
        //console.log('xxx',this.global.GetTokenDetail("ssNameEN"))
        this.http.get("AC","SNIE002_GetDateControl")
            .subscribe(res => {
                this.DOCUMENT_DATE = res.Table[0].CURRENT_DATE;
        })

    }


    Search(){
      //this.ClearParamData();
      if(!this.Params.DOCUMENT_TYPE || !this.Params.PART_NO){
        this.tableData = []
        return;
      }else{
        this.tableData = [];
        this.http.post("AC","SNIE002_PREPARE_DOCUMENT",this.Params)
        .subscribe(res =>{
         
           this.tableData = res.Table;

           this.ParamsData.TotalNetQty = res.Table.map(x => x.NET_QTY).reduce((prev, next) => prev + next);
           this.ParamsData.LockMsQty = this.ParamsData.TotalNetQty;
           this.ParamsData.StockMsQty = res.Table1[0].STOCK_MS_QTY
           this.ParamsData.AverageCost = res.Table1[0].AVERAGE_COST
           this.tblFooterDetail[2].value = this.ParamsData.LockMsLabel + ' : ' + this.ParamsData.StockMsQty
           this.Searched = true;
        })
      }

    }

    SelectedDocument(event){
 
      this.Params.DOCUMENT_TYPE = event.DOC_NOTE;
      this.Params.DOC_NAME = event.DOC_NOTE_NAME
      this.Params.REVERSE_DOC_TYPE = event.DOC_REVERSE

      if(this.Params.DOCUMENT_TYPE == 'SP'){
        this.ParamsData.LockMsLabel = "Stock Suspend Q'ty"
      }else{
        this.ParamsData.LockMsLabel = "Stock Transfer Q'ty"
      }
    }

    Clear(){
      this.Params = this.global.ClearObject(this.Params)
      this.Searched = false;
      this.ClearParamData();
      this.tableData = [];
      this.Saved = false;
    }

    ReverseQtyChange(event){

        this.ParamsData.TotalReverseQty = this.selection.selected.map(x => x.REVERSE_QTY).reduce((prev,next) => prev + next)
        this.tableData = this.tableData.slice()
      // this.ParamsData.TotalNetQty += event
      // this.ParamsData
    }

    Save(){

     
      if(this.selection.selected.length == 0 || this.ParamsData.TotalReverseQty < 1){
        this.modal.warning("Please select document to reverse!",this.viewref)
      }else if(this.ParamsData.TotalReverseQty > this.ParamsData.StockMsQty){
        this.modal.warning("Please recheck Net QTY with Stock Master!",this.viewref)
      }else{
        this.modal.confirm("Do you want to save changed you have made?",this.viewref,this.ConfirmSave)
      }    
    }

    ConfirmSave = () => {

      this.selection.selected.map(x =>{
        x.REVERSE_DOC_TYPE = this.Params.REVERSE_DOC_TYPE
        x.DOCUMENT_DATE = this.FormatDate(x.DOCUMENT_DATE)
      })

      this.http.post("AC","SNIE002_TRANSACTION_REVERSE",this.selection.selected)
        .subscribe(res => {
          this.ParamsData.DocNoFrom = res.DocumentList[0].TR_DOCUMENT_NO
          this.ParamsData.DocNoTo = res.DocumentList[res.DocumentList.length - 1].TR_DOCUMENT_NO

          for(var item of res.DocumentList){
            let index = this.tableData.findIndex(x => x.DOCUMENT_NO == item.DOCUMENT_NO)

            if(index > -1){
              this.tableData[index].REVERSE_DOC_NO = item.TR_DOCUMENT_NO
            }
          }

          this.tableData.slice();

          this.ParamsData.UpdateBy = this.global.GetTokenDetail("ssNameEN");
          this.ParamsData.UpdateDate = new Date();

          this.Saved = true;         
          this.modal.info('Transaction complete: '+ this.selection.selected.length + ' record applied and saved.', this.viewref);
          this.selection.clear();

        },(err => {
          console.log(err)
          this.modal.error(err,this.viewref)
        }))
    }

    isAllSelected() {
        const numSelected = this.selection.selected.length;
        const numRows = this.tableData.length;
        return numSelected === numRows;
      }
    
    Toggle() {
      // this.isAllSelected() ?
      // this.ParamsData.TotalReverseQty = 0 :
      // this.ParamsData.TotalReverseQty = this.tableData.map(x => x.NET_QTY).reduce((prev,next) => prev + next);

        if(this.isAllSelected()){
          this.selection.clear()
          this.ParamsData.TotalReverseQty = 0 
          this.tableData.map(x => {
            x.REVERSE_QTY = 0
          })
          //this.tableData.slice();
         
        }else{
          this.tableData.forEach(row => this.selection.select(row));
          this.ParamsData.TotalReverseQty = this.tableData.map(x => x.NET_QTY).reduce((prev,next) => prev + next);
          this.tableData.map(x => {
            x.REVERSE_QTY = x.NET_QTY
          })

          //this.tableData.slice();
        }
        

  
    }

    CheckboxChange(event,data){
         
          if(event.checked){
            this.ParamsData.TotalReverseQty += data.NET_QTY
          }else{
            this.ParamsData.TotalReverseQty -= data.NET_QTY
            if(this.ParamsData.TotalReverseQty < 0) this.ParamsData.TotalReverseQty = 0
          }     


          this.tableData = this.tableData.slice()
    }


    FormatDate(date) {

          let d = new Date(date);
          let Day = d.getDate().toString();
          let NewDay = Day.toString().length < 2 ? '0' + Day.toString() : Day.toString()
          let Month = d.getMonth() + 1;
          let NewMonth = Month.toString().length < 2 ? '0' + Month.toString() : Month.toString()
          let Year = d.getFullYear().toString();
        
      
          return Year + NewMonth + NewDay;
    }

    ClearParamData(){
      this.ParamsData.LockMsLabel = "Q'ty"
      this.ParamsData.LockMsQty = 0
      this.ParamsData.TotalNetQty = 0
      this.ParamsData.TotalReverseQty = 0
      this.ParamsData.StockMsQty = 0
      this.ParamsData.DocNoFrom = null
      this.ParamsData.DocNoTo = null
      this.ParamsData.UpdateBy = null
      this.ParamsData.UpdateDate = null
    }
}

