import { Component, OnInit, ViewChild, ViewContainerRef, ElementRef } from '@angular/core'
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { DialogTemplateComponent } from 'src/app/components/shared/dialog-template/dialog-template.component';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';
import * as moment from 'moment';
import { NgForm } from '@angular/forms';

@Component({

    selector: 'snse003',
    templateUrl: './SNSE003.component.html',
    styleUrls: ['./SNSE003.component.css']

})

export class SNSE003Component implements OnInit {

    public param: any = {};
    public orderList: Array<any>;
    public orderHeader: any;
    public orderDetail: Array<any>;
    public customerData: any;
    public orderClassList: Array<any>;
    public orderTypeList: Array<any> = [
        { ORDER_TYPE: '1', DESCRIPTION: 'E/O', REF_ORDER_CLASS: ['1', '2'] },
        { ORDER_TYPE: '2', DESCRIPTION: 'Firm', REF_ORDER_CLASS: ['3', '6'] },
        { ORDER_TYPE: '3', DESCRIPTION: 'R/O', REF_ORDER_CLASS: ['1', '2', '4'] },
        { ORDER_TYPE: '4', DESCRIPTION: 'C/O', REF_ORDER_CLASS: ['5'] },
        { ORDER_TYPE: '6', DESCRIPTION: 'Oil', REF_ORDER_CLASS: ['7'] }
    ];
    public IsEdit: boolean = false;
    public IsSearch: boolean = true;

    @ViewChild("headerForm") headerForm: NgForm;
    @ViewChild("orderDialog") orderDialog: DialogTemplateComponent;

    public CustomerLookupConfig: any = {
        ColName: "CODE_NAME",
        PlaceholderText: "Select Customer",
        SourceController: "SL",
        SourceMethodName: "SNSE003_GetCustomer",
        NoOfShowRecords: 50,
        MinLengthSearch: 0,
        UpperCase: true
    };
    public BranchLookupConfig: any = {
        ColName: "LOOKUP_BRANCH_NAME",
        PlaceholderText: "Select Customer",
        SourceController: "SL",
        SourceMethodName: "SNSE003_GetCustomerBranch",
        NoOfShowRecords: 50,
        MinLengthSearch: 0,
        SourceParams: {
            CUSTOMER_CODE: null
        },
        UpperCase: true
    };

    public PartNoLookupConfig: any = {
        ColName: "LOOKUP_PART_NAME",
        PlaceholderText: "Select Part No.",
        SourceController: "SL",
        SourceMethodName: "SNSE003_GetParts",
        NoOfShowRecords: 20
    }

    public RouteLookupConfig: any = {
        ColName: "LOOKUP_ROUTE",
        PlaceholderText: "Select Delivery Route",
        SourceController: "wPMS",
        SourceMethodName: "GetDeliveryRoute",
        NoOfShowRecords: 40,
        MinLengthSearch: 0,
        UpperCase: true
    }

    public TransportLookupConfig: any = {
        ColName: "LOOKUP_TRANSPORT",
        PlaceholderText: "Select Transport Code",
        SourceController: "wPMS",
        SourceMethodName: "GetTransportCode",
        NoOfShowRecords: 40,
        MinLengthSearch: 0,
        UpperCase: true
    }

    constructor(
        private http: HttpService,
        private modal: ModalService,
        private viewref: ViewContainerRef,
        private el: ElementRef,
        private global: Globals
    ) { }

    ngOnInit() {
        this.GetOrderClass();
    }

    Search() {
        this.orderList = [];
        this.http.get("SL", "SNSE003_GetOrderList"
            , this.param.CUSTOMER_CODE || 'null'
            , this.param.BRANCH_CODE || 'null'
            , this.param.ORDER_NO || 'null'
            , this.global.ConvertDateToFormatSTD(this.param.ORDER_DATE) || 'null')
            .subscribe(res => {
                this.orderList = res.Table;
            })
    }

    ViewOrder(order) {
        this.orderDetail = [];

        this.http.get("SL", "SNSE003_GetOrderDetail", order.ORDER_NO, order.CUSTOMER_CODE)
            .subscribe(res => {
                this.orderHeader = res.Table[0];
                this.orderDetail = res.Table1;

                this.IsSearch = false;
                this.IsEdit = false;
            })
    }

    AddOrder() {
        this.IsSearch = false;
        this.IsEdit = true;
        this.orderDetail = [];
        this.orderHeader = {};
        this.customerData = {};
        this.orderHeader.ORDER_DATE = moment();
        this.orderHeader.BO_FLAG = 'Y';
        this.orderHeader.DELIVERY_CODE = '03';
        this.CreateDetailRow(0);
        // this.orderDialog.OpenDialog();
    }

    Save() {
        if (this.headerForm.valid) {
            if (this.orderHeader.ORDER_CLASS == "7") {
                if (this.orderHeader.CREDIT_LIMIT - this.CalTotalCreditAmount() < 0) {
                    this.modal.error("THIS CUSTOMER OVER CREDIT LIMIT.", this.viewref);
                    return;
                }
            }
            let detailRows = this.orderDetail.filter(v => v.ORDER_PART_NO)

            if (detailRows.length <= 0) {
                this.modal.warning("Please select at least 1 Parts.", this.viewref)
                return;
            }
            if (detailRows.find(v => v.EDIT === "EDIT" && ((!v.QUANTITY || v.QUANTITY === 0) || (!v.UNIT_PRICE || v.UNIT_PRICE === 0)))) {
                this.modal.warning("Some record in transaction detail have unfinished detail.", this.viewref);
                return;
            }
            this.modal.confirm('Do you want to save changed you have made?', this.viewref,
                () => {
                    this.orderHeader.PART_LIST = this.orderDetail.filter(v => v.ORDER_PART_NO);
                    this.orderHeader._ORDER_DATE = this.global.ConvertDateToFormatSTD(this.orderHeader.ORDER_DATE);

                    this.http.post("SL", ["SNSE003_SaveDocument", this.orderHeader.CUSTOMER_CODE, this.orderHeader.BRANCH_CODE, this.orderHeader.ORDER_NO], this.orderHeader)
                        .subscribe(res => {
                            this.modal.info('Transaction complete: applied and saved.', this.viewref);
                            this.ViewOrder(this.orderHeader);
                        })
                }, () => { });

        } else {
            this.modal.warning("Please fill all required(*) fields.", this.viewref);
        }
    }

    CreateDetailRow(tblIndex) {
        let currentMaxRow: number = this.orderDetail.length || 0;
        let nextMaxRow: number = (Math.floor(currentMaxRow / 10) + 1) * 10;

        if (currentMaxRow - tblIndex <= 2) {
            for (let i = currentMaxRow; i < nextMaxRow; i++) {
                this.orderDetail.push({
                    STATUS: 'N'
                });
            }

            this.orderDetail = this.orderDetail.slice();
        }

    }

    GetOrderClass() {
        this.http.post("wPMS", ["GetOrderClass", "null", "10"], { JOB_TYPE: 2 })
            .subscribe(result => {
                this.orderClassList = result.Table;
            })
    }

    CheckActiveRow(index, data) {
        if (this.headerForm.valid && data.ORDER_PART_NO) {
            this.CreateDetailRow(index);
            return true;
        }
        return false;
    }

    CheckOrder(ref) {
        this.http.get("SL", "SNSE003_CheckOrder", this.orderHeader.CUSTOMER_CODE || 'null', this.orderHeader.ORDER_NO || 'null')
            .subscribe(res => {
                if (res?.Result === "Fail") {
                    this.modal.error(res.Message, this.viewref);
                    if (ref === 'customercode') {
                        this.orderHeader.CUSTOMER_CODE = null;
                        this.orderHeader.CUSTOMER_NAME = null;
                        this.orderHeader.CREDIT_LIMIT = null;
                    } else if (ref === "orderno") {
                        this.orderHeader.ORDER_NO = null;
                    }

                    return;
                }

                if (ref === "orderno") {
                    this.orderHeader.ORDER_CLASS = this.orderHeader.ORDER_NO.substr(0, 1)
                    this.OrderClassChange(this.orderHeader.ORDER_CLASS);
                }

            }, (err) => {
                this.modal.error(err.Message, this.viewref);
            })
    }

    OrderQtyChange(evt, data) {

        data.STATUS = 'N';
        data.REASON_CODE = '0';

        if (parseFloat(data.ORDER_QTY) % parseFloat(data.SALES_PACKAGE) > 0) {
            this.modal.error("ไม่ได้สั่งซื้อตาม Sales package!! (" + data.SALES_PACKAGE + ")", this.viewref);

            if (data.STATUS === 'N') {
                data.STATUS = 'W';
                data.REASON_CODE = '103';
            }
        }

        this.CheckCampaign(evt, data);
    }

    CheckCampaign(evt, data) {
        if (data.ORDER_PART_NO) {
            this.http.post("SL", "SNSE003_GetCampaignSpecialDiscount",
                {
                    ORDER_NO: this.orderHeader.ORDER_NO,
                    ORDER_CLASS: this.orderHeader.ORDER_CLASS,
                    ORDER_DATE: this.global.ConvertDateToFormatSTD(this.orderHeader.ORDER_DATE),
                    SALES_CHANNEL: this.orderHeader.SALES_CHANNEL,
                    CUSTOMER_CODE: this.orderHeader.CUSTOMER_CODE,
                    BRANCH_CODE: this.orderHeader.BRANCH_CODE,
                    ORDER_PART_NO: data.ORDER_PART_NO,
                    ORDER_QTY: data.ORDER_QTY,
                    PART_LIST: this.orderDetail.map(v => v.ORDER_PART_NO).join(",").replace(/(\,)+$/g, '')
                }).subscribe(res => {
                    if (res.CAMPAIGN_ID && res.CAMPAIGN_ID != 'null') {

                        if (res.CAMPAIGN_TYPE == 'P' && data.CAMPAIGN_ID != res.CAMPAIGN_ID) {
                            this.orderHeader.APPLY_CAMPAIGN_STATUS = 'Y';
                        }

                        data.DISCOUNT_CODE = res.DISCOUNT_CODE != 'null' ? res.DISCOUNT_CODE : null;

                        data.CAMPAIGN_ID = res.CAMPAIGN_ID;
                        data.CAMPAIGN_TYPE = res.CAMPAIGN_TYPE;
                        data.CAMPAIGN_REF = res.CAMPAIGN_REF;
                        data.DSP_CAMPAIGN_NAME = res.DSP_CAMPAIGN_NAME;
                        data.DISCOUNT_RATE1 = res.DISCOUNT_RATE1;
                        data.DISCOUNT_RATE2 = res.DISCOUNT_RATE2;
                        data.DISCOUNT_RATE3 = res.DISCOUNT_RATE3;
                        data.UNIT_PRICE_B = res.UNIT_PRICE_B;
                        data.UNIT_PRICE = res.UNIT_PRICE;
                    }
                })
        }
    }

    SetCustomerLookup(cust: any) {
        this.orderHeader.CUSTOMER_CODE = cust.CUSTOMER_CODE;
        this.orderHeader.CUSTOMER_NAME = cust.CUST_NAME_EN;
        this.orderHeader.CREDIT_LIMIT = cust.CREDIT_LIMIT;
        this.customerData.CREDIT_LIMIT = cust.CREDIT_LIMIT;
        this.orderHeader.BRANCH_CODE = null;
        this.orderHeader.BRANCH_NAME = null;
        this.BranchLookupConfig.SourceParams.CUSTOMER_CODE = cust.CUSTOMER_CODE;

        this.OrderClassChange(this.orderHeader.ORDER_CLASS);
    }

    SetBranchLookup(branch) {
        this.orderHeader.BRANCH_CODE = branch.BRANCH_CODE;
        this.orderHeader.BRANCH_NAME = branch.BRANCH_NAME_TH;
        this.customerData.ROUTE_CODE_RO = branch.ROUTE_CODE_RO;
        this.customerData.TRANSPORT_RO = branch.TRANSPORT_RO;
        this.customerData.ROUTE_CODE_EO = branch.ROUTE_CODE_EO;
        this.customerData.TRANSPORT_EO = branch.TRANSPORT_EO;

        this.OrderClassChange(this.orderHeader.ORDER_CLASS);
    }

    SetNewPartNo(part: any, data: any) {
        this.http.get("SL", "SNSE003_SNSC003"
            , this.orderHeader.CUSTOMER_CODE
            , this.global.ConvertDateToFormatSTD(this.orderHeader.ORDER_DATE)
            , part.PART_NO
            , this.orderHeader.ORDER_CLASS
            , part.VENDOR_CODE)
            .subscribe(result => {
                data.ORDER_QTY = 0;
                data.DISCOUNT_GROUP = result.DISC_GROUP;
                data.RETAIL_PRICE_B = result.RETAIL_D;
                data.UNIT_PRICE_B = result.UNIT_D;
                data.OVERSEA_FLAG_C = result.OVERSEAFLAG;
                data.DISCOUNT_RATE1 = result.DISC_1;
                data.DISCOUNT_RATE2 = result.DISC_2;
                data.DISCOUNT_RATE3 = result.DISC_3;
                data.AVERAGE_COST = result.AVG_COST;
                data.STANDARD_COST = result.STD_COST;

                this.orderHeader.DISCOUNT_GROUP = data.DISCOUNT_GROUP;
                data.RETAIL_PRICE = data.RETAIL_PRICE_B;
                data.UNIT_PRICE = data.UNIT_PRICE_B;
                data.UNIT_EDP = data.UNIT_PRICE
                data.RETAIL_PRICE_C = 0;
                data.UNIT_PRICE_C = 0;
            })
        data.ORDER_PART_NO = part.PART_NO;
        data.ORDER_PART_NAME = part.PART_NAME;
        data.UNIT_PRICE_EDITABLE = part.EDITABLE;
        data.SALES_PACKAGE = part.SALES_PACKAGE
    }

    SetRouteCode(route) {
        this.orderHeader.ROUTE_CODE = route.ROUTE_CODE;
    }

    SetTransCode(trans) {
        this.orderHeader.TRANSPORT_CODE = trans.TRANSPORT_CODE;
    }

    OrderClassChange(orderClass) {
        this.orderHeader.ORDER_TYPE = null
        if (orderClass) {
            this.orderHeader.ROUTE_CODE = (orderClass == '1' || orderClass == '2') ? this.customerData.ROUTE_CODE_EO : this.customerData.ROUTE_CODE_RO;
            this.orderHeader.TRANSPORT_CODE = (orderClass == '1' || orderClass == '2') ? this.customerData.TRANSPORT_EO : this.customerData.TRANSPORT_RO;
            this.orderHeader.ORDER_TYPE = this.orderTypeList.filter(v => v.REF_ORDER_CLASS.indexOf(orderClass) >= 0)[0]?.ORDER_TYPE;
        } else {
            this.orderHeader.ROUTE_CODE = null;
            this.orderHeader.TRANSPORT_CODE = null;
        }
    }


    CalTotalCreditAmount() {
        return this.orderDetail.reduce((prev, currObj) => prev + (parseFloat(currObj.ORDER_QTY) * parseFloat(currObj.UNIT_PRICE)), 0);
    }
    
    CalTotalAmt() {
        return this.orderDetail.reduce((o, n) => o + (parseFloat(n.ORDER_QTY || 0) * parseFloat(n.UNIT_PRICE || 0)), 0)
    }
    CalTotalQty() {
        return this.orderDetail.reduce((o, n) => o + parseFloat(n.ORDER_QTY || 0), 0)
    }

    BackToGrid() {
        this.IsSearch = true;
    }

}
