import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';

@Component({
  selector: 'SNSE011_N',
  templateUrl: './SNSE011_N.component.html',
  styleUrls: ['./SNSE011_N.component.css']
})



export class SNSE011_NComponent implements OnInit {

  public params = {
    CUSTOMER_CODE: null,
    CUSTOMER_NAME: null,
    BRANCH_CODE: null,
    ORDER_NO: null,
    ORDER_DATE: null
  }

  public TOTAL_QUANTITY: number = 0;
  public TOTAL_AMOUNT: number = 0;
  public IsSearch: boolean = true;

  constructor(
    private http: HttpService,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  public tableData: any;
  public DataIsSelected: any = [];

  public orderHeader: any;
  public orderList: Array<any> = [];
  public orderStatus: Array<any>;

  ngOnInit() {
  }

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_NAME",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNSE011_getCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public lookupOrderNoConfig: any = {
    ColName: "ORDER_NO",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE011_getOrderNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  Search = () => {
    this.orderList = [];
    this.http.get("SL", "SNSE011_N_GetOrderList"
      , this.params.CUSTOMER_CODE || 'null'
      , this.params.BRANCH_CODE || 'null'
      , this.params.ORDER_NO || 'null'
      , this.global.ConvertDateToFormatSTD(this.params.ORDER_DATE) || 'null')
      .subscribe(res => {
        this.orderList = res.Table;
      })
  }

  ViewOrder(orderHeader) {
    this.orderHeader = orderHeader;
    this.orderStatus = [];
    this.IsSearch = false;

    this.http.get("SL", "SNSE011_N_GetDetail", orderHeader.CUSTOMER_CODE, orderHeader.ORDER_NO)
      .subscribe(res => {
        this.orderStatus = res.Table;
      })
  }

  isPartialSelected() {
    let selected: number = this.orderStatus.filter(v => v.selected).length || 0;
    let all: number = this.orderStatus.length || 0;
    return all > 0 && selected > 0 && selected < all;
  }

  isAllSelected() {
    let selected: number = this.orderStatus.filter(v => v.selected).length || 0;
    let all: number = this.orderStatus.length || 0;
    return all > 0 && selected === all;
  }

  Toggle() {
    if (this.isAllSelected()) {
      this.orderStatus.forEach(row => row.selected = false);
    } else {
      this.orderStatus.forEach(row => {
        row.selected = true;
      });
    }

    this.orderStatus = [...this.orderStatus]
  }
  CheckBoxChanged(event, data) {
    data.selected = event.checked;
  }

  Save() {
    if (this.orderStatus.find(v => v.selected)) {
      this.modal.confirm('Are you sure to cancel selected rows?', this.viewref, this.Update)
    } else {
      this.modal.warning("Please select at least 1 item.", this.viewref);
      return;
    }
  }

  Update = () => {
    let selectedRow = this.orderStatus.filter(v => v.selected);

    this.http.post('SL', ['SNSE011_N_Process', this.orderHeader.CUSTOMER_CODE, this.orderHeader.ORDER_NO], selectedRow)
      .subscribe(res => {
        this.modal.info("Cancel back order completed.", this.viewref);
        this.IsSearch = true;
        this.Search();
      }, err => {
        this.modal.error("Update failed, please contact administrator to resolve.", this.viewref);
      })
  }

  BackToGrid() {
    this.IsSearch = true;
  }

  CalTotalAmt() {
    return this.orderStatus.reduce((o, n) => o + (n.selected && parseFloat(n.NET_AMT_B)), 0)
  }
  CalTotalQty() {
    return this.orderStatus.reduce((o, n) => o + (n.selected && parseFloat(n.ACCEPT_QTY)), 0)
  }
}
