import { Component, OnInit, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';

@Component({
  selector: 'snpe002',
  templateUrl: './snpe002.component.html',
  styleUrls: ['./snpe002.component.css']
})

export class SNPE002Component implements OnInit {

  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private global: Globals,
    private route: ActivatedRoute
  ) {

  }

  public dataList: any = [];
  private oldDataList: any = [];
  public vendorList: any = [];
  public vendor: string = "";
  public vendorCode: string;

  public counter: number = 0;

  public lookupConfig: any = {
    ColName: "LOOKUP_VENDOR_NAME",
    PlaceholderText: "Select Vendor",
    SourceController: "wPMS",
    SourceMethodName: "GetVendorCode",
    NoOfShowRecords: 50,
    UpperCase: true
  }

  public tblFooter: any = [
    {
      fieldName: "PO_NO",
      value: "Total",
      show: true
    },
    {
      fieldName: "ITEM_QTY",
      show: true
    },
    {
      fieldName: "NET_AMT_C",
      show: true
    }
  ]

  ngOnInit() {
    // this.GetCPSData();
    // console.log(this.global.GetRoleDetail());
  }

  GetCPSData() {
    this.dataList = [];
    this.oldDataList = [];
    this.http.get("IC", "SNPE002_GetCPSData", this.vendorCode)
      .subscribe((result: any) => {
        this.dataList = result.Table;
        this.oldDataList = JSON.parse(JSON.stringify(this.dataList));
      })
  }

  SaveCPSData() {
    let errorMsg: string = "";
    let changeRecords: Array<any> = this.dataList.filter(d => {
      let changeResult: boolean = true;
      if (d.OLD_SENDDATA_FLAG !== d.SEND_DATA_FLAG) {
        if (d.SEND_DATA_FLAG && d.SEND_DATA_FLAG !== 'N' && d.SEND_DATA_FLAG !== 'Y') {
          changeResult = false;
          errorMsg = "Invalid value character, Please check."
        }
        if (d.OLD_SENDDATA_FLAG === 'C') {
          changeResult = false;
          errorMsg = "UPDATE SEND_FLAG = C,PLEASE CHECK"
        }
      } else {
        changeResult = false;
      }

      return changeResult;
    })

    if (errorMsg !== "") {
      this.modal.error(errorMsg, this.viewref);
      return;
    }

    if (changeRecords.length > 0) {
      this.modal.confirm("Are you sure to save changes?", this.viewref,
        () => {
          this.http.post("IC", "SNPE002_SaveCPSData", JSON.stringify(changeRecords))
            .subscribe(result => {
              if (result === "Done") {
                this.modal.info("FRM-40400: Transaction complete: " + changeRecords.length.toString() + " records applied and saved.", this.viewref);
                this.GetCPSData();
              }
            }, (err) => {
              console.log(err, 'err')
            })
        },
        () => { })
    } else {
      this.modal.error("There is no change record.", this.viewref);
    }
  }

  SetVendorCodeLookup(value) {
    this.vendor = value.LOOKUP_VENDOR_NAME;
    this.vendorCode = value.VENDOR_CODE;

    this.GetCPSData();
  }

  CheckboxChange(evt, data) {
    data.SEND_DATA_FLAG = evt.checked ? 'Y' : 'N';
  }

  CheckChange() {
    return JSON.stringify(this.oldDataList) !== JSON.stringify(this.dataList);
  }

}



