import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from '../../../core/modal.service';
import { SelectionModel } from '@angular/cdk/collections';

@Component({
  selector: 'snse158',
  templateUrl: './snse158.component.html',
  styleUrls: ['./snse158.component.css']
})



export class SNSE158Component implements OnInit {


  constructor(
    private http: HttpService,
    private router: Router,
    private route: ActivatedRoute,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { 

  }

  public tabledata: any = []
  public PROCESS_LOG: any = []
  public CustomerList: any = []
  public updStatus: any
  public DataIsSelected: any = [];
  public selection = new SelectionModel<any>(true, []);
  public disableCheckAll: boolean = true;

  @ViewChild("dialogEditUPDStatus") dialogEditUPDStatus: any

  public params = {
    VENDOR_CODE: null,
    PART_NO: null,
    CREATE_PGM: null,
    UPD_STATUS: null,
    FROM_DATE: null,
    TO_DATE: null

  }

  public ConfigVendorCode: any = {
    ColName: "LOOKUP_VENDOR_CODE",
    PlaceholderText: "Select Vendor Code",
    SourceController: "IC",
    SourceMethodName: "SNSE158_getVendorCode",
    NoOfShowRecords: 20,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public ConfigPartNo: any = {
    ColName: "LOOKUP_PART_NO",
    PlaceholderText: "Select Part No",
    SourceController: "IC",
    SourceMethodName: "SNSE158_getPartNo",
    NoOfShowRecords: 100,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetVendorCode(values: any) {
    this.params.VENDOR_CODE = values.VENDOR_CODE
  }

  public SetPartNo(values: any) {
    this.params.PART_NO = values.PART_NO
  }

  public Search() {
    this.tabledata = [];
    this.disableCheckAll = this.params.UPD_STATUS !== 'N';

    this.http.post("IC", "SNSE158_getSearch", this.params)
      .subscribe(res => {
        this.tabledata = res.Table;
        this.tabledata.forEach((e) => {
          if (e.DECODE_UPD_STATUS == '1') {
            this.selection.select(e);        
          }
        })
      })
  }


  public UpdateRetailPrice() {
    this.modal.confirm("Do you want to save your change?", this.viewref,
      () => {
        this.http.post('IC', 'SNSE158_Update_Status_Y', this.DataIsSelected)
          .subscribe(res => {
            if (this.DataIsSelected.length == 0) {
              this.modal.error("Please select some data", this.viewref)
            }
            if (res.Table[0].STATUS === "Done") {
      
              this.modal.info('Save successfully : ' + this.DataIsSelected.length + ' data', this.viewref)
              this.DataIsSelected = []
              this.Search();
            } 
          }, (err) => {
            console.log(err, 'err')
          })
      }, () => { })
  }

  public CancelPartPrice() {
    this.modal.confirm("Do you want to save your change?", this.viewref,
      () => {
        this.http.post('IC', 'SNSE158_Update_Status_C', this.DataIsSelected)
          .subscribe(res => {
            if (this.DataIsSelected.length == 0) {
              this.modal.error("Please select some data",this.viewref)
            }
            if (res.Table[0].STATUS === "Done") {
              this.modal.info('Save successfully : ' + this.DataIsSelected.length + ' data', this.viewref)
              this.DataIsSelected = []
              this.Search();
            }
          }, (err) => {
            console.log(err, 'err')
          })
      }, () => { })
  }


  public ExportExcel() {
    this.http.Download("IC", "SNSE158_Export_Excel", JSON.stringify(this.tabledata))
      .subscribe(res => {
        if (res) {
          this.WriteContents(res)
          this.PROCESS_LOG.push('Export complete ' + this.tabledata.length + ' records.');
        } else {
          this.modal.error('Download not complete', this.viewref)
        }
      })
  }

  public WriteContents(content) {
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    var date_export = new Date();
    a.href = URL.createObjectURL(file);
    a.download = "SNSE158" + "_" + date_export.getFullYear() + "/" + (date_export.getMonth() + 1) + "/" + date_export.getDate() + ".csv";
    a.click();
  }

  public isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.tabledata.length;
    return numSelected === numRows;
  }

  public Toggle() {
    //console.log(this.isAllSelected());
    if (this.isAllSelected()) {
      this.selection.clear()
      this.tabledata.map(x => {
        this.DataIsSelected = [];
      })
    } else {
      this.selection.clear();
      this.tabledata.forEach(row => this.selection.select(row));
      this.DataIsSelected = [];
      this.tabledata.map(x => {
        this.DataIsSelected.push(x);
      })
    }
  }

  public CheckboxChange(event, data) {
    if (event.checked) {
      this.DataIsSelected.push(data);
    }
    else {
      this.DataIsSelected.splice(this.DataIsSelected.indexOf(data), 1);
    }
  }

  ngOnInit() {
    
  }
}


