import { Component, OnInit, ViewEncapsulation, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { FormGroup, FormControl, FormBuilder } from '@angular/forms'
import { Router, ActivatedRoute } from '@angular/router';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from '../../../core/global';
import { AuthDecode } from 'src/app/core/auth-decode.service';

@Component({
  selector: 'snse201',
  templateUrl: './SNSE201.component.html',
  styleUrls: ['./SNSE201.component.css']
})

export class SNSE201Component implements OnInit {
  public params: any = {
    MONTH_REPORT: null
  }

  public Data: any = {
    RECOMMEND_ID: null,
    DESCRIPTION: null,
    START_DATE: null,
    END_DATE: null,
    SOS_DATE: null,
    DURATION_MONTH: null,
    FILLRATE_OBJ: null,
    ACTIVE_FLAG: null
  };

  public Data2: any = {
    RECOMMEND_ID: null,
    DESCRIPTION: null,
    START_DATE: null,
    END_DATE: null,
    MONTH_REPORT: null
  };

  public Data3: any = [];

  constructor(
    private Http: HttpService,
    private router: Router,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private auth: AuthDecode,
    private global: Globals
  ) { }

  @ViewChild("dialogAdd", { static: false }) dialogAdd: any;

  private data: Array<any> = [];
  public filteredData: Array<any> = [];
  private Success: boolean = true;
  public CounterItem: number = 0;
  private origin: string = window.location.protocol + "//" + window.location.hostname + ":8090";
  public files: any = [];
  public FileName: string = ""
  public SUMList: any = [];
  public RecommendList: any = [];
  public RawDataList: any = [];
  public SumDataList: any = [];

  ngOnInit() {
    this.Http.get("IC", "SNSE201_GetRecommend")
      .subscribe(result => {
        this.RecommendList = result.Table;
      })
  }

  getDateParam(dt) {
    let year = dt.getFullYear();
    let month = (1 + dt.getMonth()).toString().padStart(2, '0');
    let day = dt.getDate().toString().padStart(2, '0');
    var p_Date = year + '-' + month;
    return p_Date;
  }

  getDateParam2(dt) {
    const monthNames = ["JAN", "FEB", "MAR", "APR", "MAY", "JUN",
      "JUL", "AUG", "SEP", "OCT", "NOV", "DEC"];

    let year = dt.getFullYear();
    let month = monthNames[dt.getMonth()];
    let day = dt.getDate().toString().padStart(2, '0');
    var p_Date = day + '-' + month + '-' + year;
    return p_Date;
  }

  public SetSelectRecommendTOP(row: any) {
    var value = this.RecommendList.find(x => x.RECOMMEND_ID == row)
    this.Data.DESCRIPTION = value.DESCRIPTION
    this.Data.START_DATE = value.START_DATE
    this.Data.END_DATE = value.END_DATE
    this.Data.SOS_DATE = value.SOS_DATE
    this.Data.DURATION_MONTH = value.DURATION_MONTH
    this.Data.FILLRATE_OBJ = value.FILLRATE_OBJ
    this.Data.ACTIVE_FLAG = value.ACTIVE_FLAG
  }

  public SetSelectRecommendBTM(row: any) {
    var value = this.RecommendList.find(x => x.RECOMMEND_ID == row)
    this.Data2.DESCRIPTION = value.DESCRIPTION
    this.Data2.START_DATE = value.START_DATE
    this.Data2.END_DATE = value.END_DATE
  }

  OnFileSelect(fileInput) {
    this.files = fileInput.target.files;
    this.FileName = this.files[0].name;
  }

  UploadData() {
    if (this.files.length == 0) {
      this.modal.error('Please Open TSV File First...', this.viewref)
    } else {
      this.data = []
      let formData = new FormData();
      formData.append('file', this.files[0]);

      this.Http.postFile('IC', 'SNSE201_UploadFile', formData)
        .subscribe(res => {
          this.data = res.Table;
          this.CounterItem = this.data.length;
          this.Success = false;
          this.files = []
          this.filteredData = this.data;
        })
    }
  }

  DownloadRawData() {
    if (this.Data2.RECOMMEND_ID && this.Data2.MONTH_REPORT) {
      var startDate = new Date(this.Data2.START_DATE);
      var endDate = new Date(this.Data2.END_DATE);
      if (this.Data2.MONTH_REPORT._d < startDate || this.Data2.MONTH_REPORT._d > endDate) {
        this.modal.warning('Please fill Month of Report in range Capturing Data', this.viewref);
      }
      else {
        var monthReport = this.getDateParam(new Date(this.Data2.MONTH_REPORT));
        this.Http.get("IC", "SNSE201_GetRawData", this.Data2.RECOMMEND_ID, monthReport)
          .subscribe(result => {
            this.RawDataList = result.Table;
            this.Http.Download('IC', 'SNSE201_DownloadRaw', JSON.stringify(this.RawDataList))
              .subscribe(res => {
                if (res) {
                  this.WriteContents(res, "RAW", this.RawDataList[0].RECOMMEND_ID)
                } else {
                  this.modal.error('Download not complete', this.viewref)
                }
              })
          })
      }
    }
    else {
      this.modal.warning('Please Select Recommend ID and Input Month of Report', this.viewref);
    }
  }

  DownloadSummaryData() {
    if (this.Data2.RECOMMEND_ID && this.Data2.MONTH_REPORT) {
      var startDate = new Date(this.Data2.START_DATE);
      var endDate = new Date(this.Data2.END_DATE);
      if (this.Data2.MONTH_REPORT._d < startDate || this.Data2.MONTH_REPORT._d > endDate) {
        this.modal.warning('Please fill Month of Report in range Capturing Data', this.viewref);
      }
      else {
        var monthReport = this.getDateParam2(new Date(this.Data2.MONTH_REPORT));
        this.Http.get("IC", "SNSE201_GetSummaryData", this.Data2.RECOMMEND_ID, monthReport)
          .subscribe(result => {
            this.SumDataList = result.Table[0]
            var DIALY_HEADER = this.SumDataList.DIALY_HEADER.split(",");
            var PART_NO = this.SumDataList.PART_NO.split(",");
            var STOCKED_ITEM = this.SumDataList.STOCKED_ITEM.split(",");
            var ORDER_RECEIVED = this.SumDataList.ORDER_RECEIVED.split(",");
            var ORDER_RECEIV_AMT = this.SumDataList.ORDER_RECEIV_AMT.split(",");
            var SHIPPED_LINES = this.SumDataList.SHIPPED_LINES.split(",");
            var SHIPPED_AMT = this.SumDataList.SHIPPED_AMT.split(",");
            var BO_LINES = this.SumDataList.BO_LINES.split(",");
            var BO_AMT = this.SumDataList.BO_AMT.split(",");
            var INITIAL_FILL = this.SumDataList.INITIAL_FILL.split(",");
            var INIT_FILL_ACT = this.SumDataList.INIT_FILL_ACT.split(",");
            for (var i = 0; i < DIALY_HEADER.length; i++) {
              this.Data3[i] = {
                "DIALY_HEADER": DIALY_HEADER[i],
                "PART_NO": PART_NO[i],
                "STOCKED_ITEM": STOCKED_ITEM[i],
                "ORDER_RECEIVED": ORDER_RECEIVED[i],
                "ORDER_RECEIV_AMT": ORDER_RECEIV_AMT[i],
                "SHIPPED_LINES": SHIPPED_LINES[i],
                "SHIPPED_AMT": SHIPPED_AMT[i],
                "BO_LINES": BO_LINES[i],
                "BO_AMT": BO_AMT[i],
                "INITIAL_FILL": INITIAL_FILL[i],
                "INIT_FILL_ACT": INIT_FILL_ACT[i]
              };
            }

            this.Http.Download('IC', 'SNSE201_DownloadSummary', JSON.stringify(this.Data3))
              .subscribe(res => {
                if (res) {
                  this.WriteContents(res, "SUM", this.Data2.RECOMMEND_ID)
                } else {
                  this.modal.error('Download not complete', this.viewref)
                }
              })
          })
      }
    }
    else {
      this.modal.warning('Please Select Recommend ID and Input Month of Report', this.viewref);
    }
  }

  WriteContents(content, type, id) {
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    a.href = URL.createObjectURL(file);
    a.download = "SNPE201" + type + id + ".csv";
    a.click();
  }


  public SaveData() {
    this.modal.confirm("Do you want to save changed you have made?", this.viewref, this.ConfirmSave)
  }

  CancelAdd() {
    this.dialogAdd.Close()
  }

  ConfirmSave = () => {
    this.Http.post('IC', 'SNSE201_SaveData', this.Data)
      .subscribe(res => {
        if (res == 'Done') {
          this.ngOnInit()
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
        }
        else {
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      })
  }
}


