import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { FormControl, Validators } from '@angular/forms';
import { MatDatepickerInputEvent } from '@angular/material/datepicker';
import { ModalService } from 'src/app/core/modal.service';
import { AutoCompleteQueryComponent } from '../../../components/shared/auto-complete-query/auto-complete-query.component';

@Component({
  selector: 'snm004p',
  templateUrl: './snm004p.component.html',
  styleUrls: ['./snm004p.component.css']
})



export class SNM004PComponent implements OnInit {


  constructor(
    private http: HttpService,
    private router: Router,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef

  ) { }

  @ViewChild("dialogAdd", { static: false }) dialogAdd: any;
  @ViewChild("dialogEdit", { static: false }) dialogEdit: any;

  @ViewChild("SalesChanel", { static: false }) SalesChanel: AutoCompleteQueryComponent;
  @ViewChild("ZoneArea", { static: false }) ZoneArea: AutoCompleteQueryComponent;
  @ViewChild("ArChanel", { static: false }) ArChanel: AutoCompleteQueryComponent;
  @ViewChild("SalesMan", { static: false }) SalesMan: AutoCompleteQueryComponent;
  @ViewChild("CountryCode", { static: false }) CountryCode: AutoCompleteQueryComponent;
  @ViewChild("LockCustomer", { static: false }) LockCustomer: AutoCompleteQueryComponent;




  public CustomerList: any = [];
  public tableData: any = [];
  public hideCols: Array<string> = []


  public ConfigCustomer: any = {
    ColName: "CODE_NAME",
    ColValue: "CUSTOMER_CODE",
    PlaceholderText: "Select Customer",
    SourceController: "wPMS",
    SourceMethodName: "GetCustomerCode",
    NoOfShowRecords: 25,
    MinLengthSearch: 3,
    UpperCase: false
  }

  public ConfigSalesChannal: any = {
    ColName: "LOOK_UP",
    ColValue: "",
    PlaceholderText: "Select Sales Channal",
    SourceController: "AC",
    SourceMethodName: "GetSalesChannal",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: false
  }

  public ConfigZoneArea: any = {
    ColName: "LOOK_UP",
    ColValue: "",
    //ColValue: "ZONE_AREA",
    PlaceholderText: "Select Zone Area",
    SourceController: "AC",
    SourceMethodName: "GetZoneArea",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: false
  }

  public ConfigLockCustomer: any = {
    ColName: "LOOK_UP",
    ColValue: "",
    PlaceholderText: "Select Lock Customer",
    SourceController: "AC",
    SourceMethodName: "GetLockCustomer",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: false
  }

  public ConfigArChannal: any = {
    ColName: "LOOK_UP",
    ColValue: "",
    PlaceholderText: "Select Ar Channel",
    SourceController: "AC",
    SourceMethodName: "GetArChannal",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: false
  }

  public ConfigSalesman: any = {
    ColName: "LOOK_UP",
    ColValue: "",
    PlaceholderText: "Select Salesman",
    SourceController: "AC",
    SourceMethodName: "GetSalesMan",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: false
  }

  public ConfigCountryCode: any = {
    ColName: "LOOK_UP",
    ColValue: "",
    PlaceholderText: "Select Country Code",
    SourceController: "AC",
    SourceMethodName: "GetCountryCode",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: false
  }


  public ConfigCurrencyCode: any = {
    ColName: "LOOK_UP",
    ColValue: "CURRENCY_CODE",
    PlaceholderText: "Select Currency Code",
    SourceController: "AC",
    SourceMethodName: "GetCurrencyCode",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: true
  }


  public COS_FORMAT = {
    'F3': false,
    'F4': false,
    'F5': false,
    'F6': false
  }


  public Params = {
    CUSTOMER_CODE: null,
    CUSTOMER_NAME: null,
    CUSTOMER_AR: null
  }

  public ParamsAdd: any = {};

  public ParamsEdit: any = {};

  CustomerCodeControl = new FormControl('', [Validators.required])
  DefualtDateEnable = new FormControl();
  DefualtDateDisable = new FormControl();

  EditDateEnable = new FormControl();
  EditDateDisable = new FormControl();
  public RoleCHG: boolean = false;

  ngOnInit() {


    this.DefualtDateEnable = new FormControl(new Date())
    this.DefualtDateDisable = new FormControl(new Date())

    this.global.GetRoleDetail().CHG === "N" ? this.RoleCHG = false : this.RoleCHG = true;
    this.global.GetRoleDetail().DEL === "N" ? this.hideCols.push("DELETE") : null;
  }


  Search() {

    this.http.post('AC', 'SNM004P_GetData', this.Params)
      .subscribe(res => {
        this.tableData = res.Table;
      })

  }

  DateChange(event: MatDatepickerInputEvent<Date>, type: string, action: string) {

    switch (action) {
      case "ADD":
        if (type == 'E') {
          this.ParamsAdd.ENABLE_DATE = event.value;
        } else {
          this.ParamsAdd.DISABLE_DATE = event.value;
        }
        break;

      case "EDIT":
        if (type == 'E') {
          this.ParamsEdit.ENABLE_DATE = event.value;
        } else {
          this.ParamsEdit.DISABLE_DATE = event.value;
        }
        break;

      default:
        console.log("action not macth")
        break;
    }




  }

  openDialog() {
    this.CustomerCodeControl.reset();
    this.SetDefaultParams();
    this.COS_FORMAT.F3 = false
    this.COS_FORMAT.F4 = false
    this.COS_FORMAT.F5 = false
    this.COS_FORMAT.F6 = false
    this.dialogAdd.OpenDialog();
  }

  SaveAdd() {

    this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmSaveAdd)

  }

  ConfirmSaveAdd = () => {

    this.CheckCosFormat('ADD');

    this.ParamsAdd.ENABLE_DATE = this.ParamsAdd.ENABLE_DATE ? this.ParamsAdd.ENABLE_DATE : new Date();
    this.ParamsAdd.DISABLE_DATE = this.ParamsAdd.DISABLE_DATE ? this.ParamsAdd.DISABLE_DATE : new Date();

    this.http.post("AC", "SNM004P_Insert", this.ParamsAdd)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
          this.SetDefaultParams();
          this.dialogAdd.Close();

        } else if (res.Table[0].STATUS == 'Duplicate') {
          this.modal.warning('No change to save. Found duplicate record.', this.viewref);
        }
        else {
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      })
  }

  CancelAdd() {
    this.dialogAdd.Close();
  }

  Edit(data) {
    this.CustomerCodeControl.reset();
    if (data.COS_FORMAT) {

      this.COS_FORMAT.F3 = data.COS_FORMAT.includes("43")
      this.COS_FORMAT.F4 = data.COS_FORMAT.includes("44")
      this.COS_FORMAT.F5 = data.COS_FORMAT.includes("45")
      this.COS_FORMAT.F6 = data.COS_FORMAT.includes("46")
    }

    this.EditDateEnable = new FormControl(data.ENABLE_DATE)
    this.EditDateDisable = new FormControl(data.DISABLE_DATE)
    this.ParamsEdit = data;
    this.dialogEdit.OpenDialog();

    setTimeout(() => {


      //this.LockCustomer.textInput = this.ParamsEdit.LOCK_CUSTOMER;
      //this.LockCustomer.query();


      this.SalesChanel.textInput = this.ParamsEdit.SALES_CHANNEL;
      this.SalesChanel.query();

      this.ZoneArea.textInput = this.ParamsEdit.ZONE_AREA;
      this.ZoneArea.query();

      this.ArChanel.textInput = this.ParamsEdit.AR_CHANNEL;
      this.ArChanel.query();

      this.SalesMan.textInput = this.ParamsEdit.SALESMAN_CODE;
      this.SalesMan.query();

      this.CountryCode.textInput = this.ParamsEdit.COUNTRY_CODE;
      this.CountryCode.query();

      this.LockCustomer.textInput = this.ParamsEdit.LOCK_CUSTOMER;
      this.LockCustomer.query();

    }, 500)
  }


  SaveEdit() {
    this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmEdit)
  }

  ConfirmEdit = () => {

    this.CheckCosFormat("EDIT");


    this.http.post("AC", "SNM004P_Update", this.ParamsEdit)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.dialogEdit.Close();
          this.Search();

        }
        else {
          console.log(res)
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      })
  }

  CancelEdit() {
    this.dialogEdit.Close()
  }

  Delete(data) {
    this.modal.confirm("Do you want to delete record?", this.viewref, () => this.ConfirmDelete(data))
  }

  ConfirmDelete(data) {

    this.http.post("AC", "SNM004P_Delete", data)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
        }
        else {
          console.log(res)
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      })
  }

  CheckCosFormat(action: string) {


    switch (action) {
      case "ADD":

        this.ParamsAdd.COS_FORMAT = null

        if (!this.COS_FORMAT.F3 && !this.COS_FORMAT.F4 && !this.COS_FORMAT.F5 && !this.COS_FORMAT.F6) {
          this.ParamsAdd.COS_FORMAT = null
        }
        else {

          if (this.COS_FORMAT.F3) this.ParamsAdd.COS_FORMAT = "43"

          if (this.ParamsAdd.COS_FORMAT != null && this.COS_FORMAT.F4) {
            this.ParamsAdd.COS_FORMAT = this.ParamsAdd.COS_FORMAT.concat('/' + "44")
          } else if (this.ParamsAdd.COS_FORMAT == null && this.COS_FORMAT.F4) {
            this.ParamsAdd.COS_FORMAT = "44"
          }

          if (this.ParamsAdd.COS_FORMAT != null && this.COS_FORMAT.F5) {
            this.ParamsAdd.COS_FORMAT = this.ParamsAdd.COS_FORMAT.concat('/' + "45")
          } else if (this.ParamsAdd.COS_FORMAT == null && this.COS_FORMAT.F5) {
            this.ParamsAdd.COS_FORMAT = "45"
          }


          if (this.ParamsAdd.COS_FORMAT != null && this.COS_FORMAT.F6) {
            this.ParamsAdd.COS_FORMAT = this.ParamsAdd.COS_FORMAT.concat('/' + "46")
          } else if (this.ParamsAdd.COS_FORMAT == null && this.COS_FORMAT.F6) {
            this.ParamsAdd.COS_FORMAT = "46"
          }
        }
        break;
      case "EDIT":

        this.ParamsEdit.COS_FORMAT = null

        if (!this.COS_FORMAT.F3 && !this.COS_FORMAT.F4 && !this.COS_FORMAT.F5 && !this.COS_FORMAT.F6) {
          this.ParamsEdit.COS_FORMAT = null
        }
        else {

          if (this.COS_FORMAT.F3) this.ParamsEdit.COS_FORMAT = "43"

          if (this.ParamsEdit.COS_FORMAT != null && this.COS_FORMAT.F4) {
            this.ParamsEdit.COS_FORMAT = this.ParamsEdit.COS_FORMAT.concat('/' + "44")
          } else if (this.ParamsEdit.COS_FORMAT == null && this.COS_FORMAT.F4) {
            this.ParamsEdit.COS_FORMAT = "44"
          }

          if (this.ParamsEdit.COS_FORMAT != null && this.COS_FORMAT.F5) {
            this.ParamsEdit.COS_FORMAT = this.ParamsEdit.COS_FORMAT.concat('/' + "45")
          } else if (this.ParamsEdit.COS_FORMAT == null && this.COS_FORMAT.F5) {
            this.ParamsEdit.COS_FORMAT = "45"
          }


          if (this.ParamsEdit.COS_FORMAT != null && this.COS_FORMAT.F6) {
            this.ParamsEdit.COS_FORMAT = this.ParamsEdit.COS_FORMAT.concat('/' + "46")
          } else if (this.ParamsEdit.COS_FORMAT == null && this.COS_FORMAT.F6) {
            this.ParamsEdit.COS_FORMAT = "46"
          }
        }
        break;
      default:
        console.log("action not macth")
        break;
    }


  }

  SetDefaultParams() {
    this.ParamsAdd = this.global.ClearObject(this.ParamsAdd);
    this.ParamsAdd.CASE_NO_AIR = '0000',
      this.ParamsAdd.CASE_NO_SEA = '0000',
      this.ParamsAdd.PAYMENT_TERM = 0,
      this.ParamsAdd.CREDIT_LIMIT = 0.00,
      this.ParamsAdd.CREDIT_BALANCE = 0.00,
      this.ParamsAdd.OVERSEA_FLAG = 'D',
      this.ParamsAdd.PRICE_TERM_CODE = 'N',
      this.ParamsAdd.REBATE_FLAG = 'N',
      this.ParamsAdd.BAL_OF_OIL_LITR = 0.00,
      this.ParamsAdd.COS_FLAG = '0',
      this.ParamsAdd.LINES_PER_INV = 1
    this.DefualtDateEnable = new FormControl(new Date())
    this.DefualtDateDisable = new FormControl(new Date())
  }

  SetFormateDate(date) {

    let d = new Date(date);

    let day = d.getDate();
    let newDay = day.toString().length < 2 ? 0 + '' + day : day
    let year = d.getFullYear()
    let month = d.getMonth() + 1;
    let newMonth = month.toString().length < 2 ? 0 + '' + month : month

    return newDay + '-' + newMonth + '-' + year;

  }

  SetLockCustomer(evt, type) {
    if (type === "Add") {
      this.ParamsAdd.LOCK_CUSTOMER = evt.REASON_CODE;
      this.ParamsAdd.LOCK_CUSTOMER_SHOW = evt.LOOK_UP;
    } else if (type === "Edit") {
      this.ParamsEdit.LOCK_CUSTOMER = evt.REASON_CODE;
      this.ParamsEdit.LOCK_CUSTOMER_SHOW = evt.LOOK_UP;
    }
  }

  SetCountryCode(evt, type) {
    if (type === "Add") {
      this.ParamsAdd.COUNTRY_CODE = evt.COUNTRY_CODE;
      this.ParamsAdd.COUNTRY_CODE_SHOW = evt.LOOK_UP;
    } else if (type === "Edit") {
      this.ParamsEdit.COUNTRY_CODE = evt.COUNTRY_CODE;
      this.ParamsEdit.COUNTRY_CODE_SHOW = evt.LOOK_UP;
    }
  }

  SetSalesMan(evt, type) {
    if (type === "Add") {
      this.ParamsAdd.SALESMAN_CODE = evt.SALESMAN_CODE;
      this.ParamsAdd.SALESMAN_CODE_SHOW = evt.LOOK_UP;
    } else if (type === "Edit") {
      this.ParamsEdit.SALESMAN_CODE = evt.SALESMAN_CODE;
      this.ParamsEdit.SALESMAN_CODE_SHOW = evt.LOOK_UP;
    }
  }

  SetARChannel(evt, type) {
    if (type === "Add") {
      this.ParamsAdd.AR_CHANNEL = evt.AR_CHANNEL;
      this.ParamsAdd.AR_CHANNEL_SHOW = evt.LOOK_UP;
    } else if (type === "Edit") {
      this.ParamsEdit.AR_CHANNEL = evt.AR_CHANNEL;
      this.ParamsEdit.AR_CHANNEL_SHOW = evt.LOOK_UP;
    }
  }

  SetZoneArea(evt, type) {
    if (type === "Add") {
      this.ParamsAdd.ZONE_AREA = evt.ZONE_AREA;
      this.ParamsAdd.ZONE_AREA_SHOW = evt.LOOK_UP;
    } else if (type === "Edit") {
      this.ParamsEdit.ZONE_AREA = evt.ZONE_AREA;
      this.ParamsEdit.ZONE_AREA_SHOW = evt.LOOK_UP;
    }
  }

  SetSalesChannel(evt, type) {
    if (type === "Add") {
      this.ParamsAdd.SALES_CHANNEL = evt.SALES_CHANNEL;
      this.ParamsAdd.SALES_CHANNEL_SHOW = evt.LOOK_UP;
    } else if (type === "Edit") {
      this.ParamsEdit.SALES_CHANNEL = evt.SALES_CHANNEL;
      this.ParamsEdit.SALES_CHANNEL_SHOW = evt.LOOK_UP;
    }
  }

  SetCurrencyCode(evt, type) {
    if (type === "Add") {
      this.ParamsAdd.CURRENCY_CODE = evt;
    } else if (type === "Edit") {
      this.ParamsEdit.CURRENCY_CODE = evt;
    }
  }

}

