import { Component, OnInit, ViewContainerRef, ViewChild, ElementRef, ViewChildren } from "@angular/core";
import { HttpService } from 'src/app/core/http.service';
//import { DialogComponent } from '../../../components/shared/dialog/dialog.component';
import { ModalService } from '../../../core/modal.service';
import * as cloneDeep from 'lodash/cloneDeep';
import { FormControl, Validators } from '@angular/forms';
import { Globals } from 'src/app/core/global';
import { ActivatedRoute } from '@angular/router';


@Component({
  selector: 'snm056s',
  templateUrl: './snm056s.component.html',
  styleUrls: ['./snm056s.component.css']
})

export class SNM056SComponent implements OnInit {

  constructor(
    private Http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private global: Globals,
    private route: ActivatedRoute
  ) {

  }

  @ViewChild("dialog", { static: false }) dialog: any;
  @ViewChildren("CalendarInput") CalendarInput: any;

  public gPROCESS_YEAR: string;
  public aData: any = [];
  public aHeaderList: any = [];
  public aHeaderListEdit: any = [];
  public filterMonth: any = [];
  public titles: string = '';
  public CheckValues: boolean = false;
  public HeaderEdit: any = []

  public Update = {
    By: null,
    Date: null
  }

  ngOnInit() {

    this.aHeaderList = this.GenerateHeader(0)

    let d = new Date()
    this.gPROCESS_YEAR = d.getFullYear().toString()
    this.GetData()


  }

  GetData() {

    this.Http.get('IC', 'SNM056S_GetCalendar', this.gPROCESS_YEAR)
      .subscribe(res => {

        if (res.Table1[0].STATUS == 'EXISTS') {
          this.aData = res.Table;
        } else {
          this.ValidateCalendar(res.Table);
        }

        this.Update.By = res.Table2[0].LAST_UPD_BY
        this.Update.Date = res.Table2[0].LAST_UPD_DATE
      })

  }

  Save() {

    let found = this.CalendarInput._results.some(x => x.nativeElement.validity.valid == false);

    if (found) {
      this.modal.error('Please input Values Only (D , W , B , M ,H)', this.viewref);
    } else {
      this.modal.confirm('Do you want to save changed you have made?', this.viewref, this.SaveCalendar)

    }

  }

  SaveCalendar = () => {

    this.Http.post('IC', 'SNM056S_UpdateCalendar', JSON.stringify(this.filterMonth))
      .subscribe(res => {
        if (res.Table[0].STATUS === "Done") {
          this.modal.info('Transaction complete: applied and saved.', this.viewref)
          this.dialog.Close()
          this.GetData();
          //this.openDialog('Message from the system', 'Success')
        } else {
          this.modal.error('No change to save. Something went wrong.', this.viewref)
        }
      }, (err) => {

        this.modal.error('No change to save. Something went wrong.', this.viewref)
      })
  }

  EditMonth(MonthNumber, Year) {

    this.aHeaderListEdit = this.GenerateHeaderForEdit(MonthNumber, Number(Year))
    this.titles = "Calendar Suggest Master - " + '' + this.GetFullMonth(MonthNumber);
    let MonthData = this.aData.filter((x, index) => x.PROCESS_MONTH == MonthNumber)
    this.filterMonth = cloneDeep(MonthData);

    setTimeout(() => { this.dialog.OpenDialog() }, 200);
  }

  keyDownFunction(event) {
    if (event.keyCode == 13) {
      this.GetData();
    }
  }

  Cancel() {
    this.dialog.Close();
  }


  ValidateCalendar(data: any) {

    let WeekEnds = []

    data.forEach(x => {
      WeekEnds = this.FindWeekEnds(x.PROCESS_MONTH, Number(x.PROCESS_YEAR));
      for (let i = 0; i < WeekEnds.length; i++) {
        x["DATE_STATUS_" + WeekEnds[i]] = "H"
      }
    })
    this.aData = data;
    this.Http.post('IC', 'SNM056S_FirstUpdate', data)
      .subscribe(res => {
      })

  }

  GenerateHeader(month) {
    let NumberHeader = [];
    for (let i = 1; i < 32; i++) {
      let newint = i.toString().length < 2 ? 0 + '' + i : i
      NumberHeader.push({ FIELD: 'DATE_STATUS_' + newint, TITLE: i })
    }

    return NumberHeader;
  }

  GenerateHeaderForEdit(month, year) {
    var days = new Date(year, month, 0).getDate();
    let NumberHeader = [];
    for (let i = 1; i < days + 1; i++) {
      let newint = i.toString().length < 2 ? 0 + '' + i : i
      NumberHeader.push({ FIELD: 'DATE_STATUS_' + newint, TITLE: i })
    }

    return NumberHeader;
  }


  GetMonthText(NumberOfMonth) {

    let MonthList = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"]
    return MonthList[Number(NumberOfMonth) - 1];

  }

  GetFullMonth(NumberOfMonth) {
    //let MonthListThai = ["มกราคม", "กุมภาพันธ์", "มีนาคม", "เมษายน", "พฤษภาคม", "มิถุนายน", "กรกฎาคม", "สิงหาคม", "กันยายน", "ตุลาคม", "พฤศจิกายน", "ธันวาคม"]
    let MonthList = ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"]
    return MonthList[Number(NumberOfMonth) - 1];

  }


  FindWeekEnds(m, y) {

    var days = new Date(y, m, 0).getDate();
    var WeekEnds = [];

    for (var i = 1; i <= days; i++) {
      var date = new Date(y, m - 1, i);
      if (date.getDay() == 6 || date.getDay() == 0) {
        let newDate = date.getDate().toString().length < 2 ? '0' + date.getDate().toString() : date.getDate().toString();
        WeekEnds.push(newDate);
      }
    };

    return WeekEnds;
  }

  CheckValue(event, fieldName) {
    if(['D','W','B','M','H'].indexOf(event.target.value) < 0){
      this.modal.error("Please input Values Only (D , W , B , M ,H)", this.viewref);

      this.filterMonth[0][fieldName] = "";
    }
  }
}
