import { Component, OnInit,ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { SelectionModel } from '@angular/cdk/collections';
import { Globals } from '../../../core/global';
import { ModalService } from '../../../core/modal.service';
import { MatDatepicker } from '@angular/material/datepicker';

@Component({
  selector: 'snpr020',
  templateUrl: './snpr020.component.html',
  styleUrls: ['./snpr020.component.css']
})



export class SNPR020Component implements OnInit {


  constructor(
    private http: HttpService,
      private router: Router,
      private global: Globals,
      private modal: ModalService,
      private viewref: ViewContainerRef
  ) { }
    selection = new SelectionModel<any>(true, []);


    public VendorConfig: any = {
        ColName: "VENDOR_TEXT",
        ColValue: "VENDOR_CODE",
        PlaceholderText: "Select Vendor Code",
        SourceController: "IC",
        SourceMethodName: "SNPR019_FindFVendor",
        NoOfShowRecords: 50,
        MinLengthSearch: 2
    }
    public InvoiceConfig: any = {
        ColName: "INVOICE_NO",
        ColValue: "INVOICE_NO",
        PlaceholderText: "Select Invoice No.",
        SourceController: "IC",
        SourceMethodName: "SNPR019_FindFInvoice",
        NoOfShowRecords: 50,
        MinLengthSearch: 3
    }

    public ConfigPart: any = {
        ColName: "LOOKUP_PART_NAME",
        ColValue: "PART_NO",
        PlaceholderText: "Select Part No.",
        SourceController: "wPMS",
        SourceMethodName: "GetPartNo",
        NoOfShowRecords: 50,
        MinLengthSearch: 5
      }


    public Params: any = {
        COMPANY_CODE: null,
        VENDOR_CODE_FROM: null,
        VENDOR_CODE_TO: null,
        INVOICE_NO_FROM: null,
        INVOICE_NO_TO: null,
        INVOICE_DATE_FROM: null,
        INVOICE_DATE_TO: null,
        PART_NO_FROM : null,
        PART_NO_TO : null
    };

  ngOnInit() {
    let d = new Date()
    this.Params.INVOICE_DATE_FROM = d
    this.Params.INVOICE_DATE_TO = d
    }

    SetFVendor(FVendorCode) {
        this.Params.VENDOR_CODE_FROM = FVendorCode;
    }
    SetLVendor(TVendorCode) {
        this.Params.VENDOR_CODE_TO = TVendorCode;
    }
    SetFInvoice(FInvoiceNo) {
        this.Params.INVOICE_NO_FROM = FInvoiceNo;
    }
    SetLInvoice(TInvoiceNo) {
        this.Params.INVOICE_NO_TO = TInvoiceNo;
    }

    ValidateDate(){
        if(this.Params.INVOICE_DATE_FROM > this.Params.INVOICE_DATE_TO){
            this.modal.warning("Defult First value is not larger than Last value",this.viewref)
        }
    }
 
    OpenReport() {

        if(this.Params.INVOICE_DATE_FROM > this.Params.INVOICE_DATE_TO){
                this.modal.warning("Defult First value is not larger than Last value",this.viewref)
            }else{

                this.global.GoToReport("PMS_RPT_WH_SNPR020", {
                    P_COMPANY_CODE : this.global.GetTokenDetail("ssComCode"),
                    P_VENDOR_CODE: this.Params.VENDOR_CODE_FROM,
                    P_VENDOR_CODE1: this.Params.VENDOR_CODE_TO,
                    P_INVOICE_NO: this.Params.INVOICE_NO_FROM,
                    P_INVOICE_NO1: this.Params.INVOICE_NO_TO,
                    P_INVOICE_DATE: this.SetformatDate(this.Params.SHIPPED_DATE_FROM),
                    P_INVOICE_DATE1: this.SetformatDate(this.Params.SHIPPED_DATE_TO),
                    P_PART_NO : this.Params.PART_NO_FROM,
                    P_PART_NO1 : this.Params.PART_NO_TO
                })
            }


       
    }

    OpendateFromPopup(datepicker: MatDatepicker<any>) {

        datepicker.open();
      }
    
      OpendateToPopup(datepicker: MatDatepicker<any>) {
    
        datepicker.open();
      }
      

    CheckExportDataCondition() {
        if (this.Params.VENDOR_CODE_From == null) {
            this.Params.VENDOR_CODE_From = this.Params.VENDOR_CODE_To;
        }
        if (this.Params.INVOICE_NO_FROM == null) {
            this.Params.INVOICE_NO_FROM = this.Params.INVOICE_NO_TO;
        }
    }


    SetformatDate(date) {
        let d = new Date(date)
        let day = d.getDate();
        let month = d.getMonth() + 1;
        let newmonth = month.toString().length < 2 ? 0 + month.toString() : month.toString();
        let year = d.getFullYear();

        return day + '-' + newmonth + '-' + year;
    }






}

