import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';
import { SelectionModel } from '@angular/cdk/collections';
@Component({

  selector: 'snse026M',
  templateUrl: './SNSE026M.component.html',
  styleUrls: ['./SNSE026M.component.css']
})

export class SNSE026MComponent implements OnInit {

  constructor(
    private Http: HttpService,
    private router: Router,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  public params: any = {}

  public tableData: any = [];
  public DataIsSelected: any = [];
  public selection = new SelectionModel<any>(true, []);

  public isProcessed: boolean = false;
  public isPrinted: boolean = false;

  ngOnInit() {
    this.GetFromDate();
    this.GetToDate();
    this.params.CNT_REC = 0;
    this.params.PICK_LOT_DATE = new Date();

    this.params.CNT_SEL = 0;
    this.params.PICK_LOT_SEQ = 0;
    this.params.LOCATION = "0";
    this.params.AUTO_PRINT = "0";
    this.params.ORDER_CLASS = "";
    this.params.PRINTER_NAME = "0";
    this.params.PRINTER = "3";
    //this.params.LOCATION_FROM = "1A";
    //this.params.LOCATION_TO = "1B";
    this.GetPickLotSeq();
    this.params.PRINTER = 'PRINTER'
    this.params.AUTO_PRINT = 'Y'
  }

  public lookupFromAllocateDateConfig: any = {
    ColName: "DIS_ALLOCATE_DATE",
    PlaceholderText: "Select Allocate Date",
    SourceController: "SL",
    SourceMethodName: "SNSE026M_getAllocateFromDate",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public SetSelectedFromAllocateDate(values: any) {
    this.params.FROM_DATE = values.DIS_ALLOCATE_DATE;
    this.params.ALLOCATE_DATE_FROM = values.ALLOCATE_DATE;
  }

  public lookupToAllocateDateConfig: any = {
    ColName: "DIS_ALLOCATE_DATE",
    PlaceholderText: "Select Allocate Date",
    SourceController: "SL",
    SourceMethodName: "SNSE026M_getAllocateToDate",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public SetSelectedToAllocateDate(values: any) {
    this.params.TO_DATE = values.DIS_ALLOCATE_DATE;
    this.params.ALLOCATE_DATE_TO = values.ALLOCATE_DATE;
  }

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNSE026M_getCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public SetSelectedCustomerCode(values: any) {
    this.params.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = values.CUSTOMER_NAME;
  }

  public lookupOrderNoConfig: any = {
    ColName: "LOOKUP_ORDER_NO",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE026M_GetOrderNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public SetSelectedOrderNo(value: any) {
    this.params.ORDER_NO = value.ORDER_NO;
  }

  public lookupAcceptPartNoConfig: any = {
    ColName: "LOOKUP_ACCEPT_PART_NO",
    PlaceholderText: "Select Accept Part No",
    SourceController: "SL",
    SourceMethodName: "SNSE026M_GetAcceptPartNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public SetSelectedAcceptPartNo(value: any) {
    this.params.ACCEPT_PART_NO = value.ACCEPT_PART_NO;
  }

  private GetPickLotSeq() {
    this.Http.get('SL', 'SNSE026M_GetPickLotSeq')
      .subscribe(res => {
        if (res.Table[0].PICK_LOT_SEQ) {
          this.params.PICK_LOT_SEQ = res.Table[0].PICK_LOT_SEQ
        }
        else {
          this.params.PICK_LOT_SEQ = 1;
        }
      });
  }

  //GetPickingNo() {
  //  this.Http.get('SL', 'SNSE026M_GetPickingNo')
  //    .subscribe(res => {
  //      this.params.PICKING_LIST_NO_2 = res.Table[0].PICKING_LIST_NO
  //    });
  //}

  GetToDate() {
    this.params.ALLOCATE_DATE = 'TO'
    this.Http.post('SL', 'SNSE026M_FirstLast_Date', this.params)
      .subscribe(res => {
        this.params.TO_DATE = res.Table[0].DIS_ALLOCATE_DATE
        this.params.ALLOCATE_DATE_TO = res.Table[0].ALLOCATE_DATE;
      });
  }

  GetFromDate() {
    this.params.ALLOCATE_DATE = 'FROM'
    this.Http.post('SL', 'SNSE026M_FirstLast_Date', this.params)
      .subscribe(res => {
        this.params.FROM_DATE = res.Table[0].DIS_ALLOCATE_DATE
        this.params.ALLOCATE_DATE_FROM = res.Table[0].ALLOCATE_DATE;
      });
  }

  Search = () => {
    this.tableData = []
    this.DataIsSelected = []
    this.Http.post('SL', 'SNSE026M_getData', this.params)
      .subscribe(res => {
        this.selection.clear()
        this.tableData = res.Table;
        this.params.PICKING_LIST_NO = null;
        this.params.CNT_REC = this.tableData.length;
        this.params.CNT_SEL = this.tableData.length;
        this.isPrinted = false;

        if (this.tableData.length > 0) {

          this.tableData.forEach((x) => {
            x.PICK_LOT_DATE = this.params.PICK_LOT_DATE
            x.PICK_LOT_SEQ = this.params.PICK_LOT_SEQ
            this.selection.select(x)
            this.DataIsSelected.push(x);
          });
        }
      });
  }

  isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.tableData.length;
    return numSelected === numRows;
  }

  Toggle() {
    if (this.isAllSelected()) {
      this.selection.clear()
      this.tableData.map(x => {
        this.DataIsSelected = [];
      })
    } else {
      this.tableData.forEach(row => this.selection.select(row));
      this.DataIsSelected = [];
      this.tableData.map(x => {
        x.PICK_LOT_DATE = this.params.PICK_LOT_DATE
        x.PICK_LOT_SEQ = this.params.PICK_LOT_SEQ
        this.DataIsSelected.push(x);
      })
    }
    console.log(this.DataIsSelected)
    this.params.CNT_SEL = this.DataIsSelected.length;
  }

  CheckboxChange(event, data) {
    if (event.checked) {
      //data.PICK_LOT_DATE = this.params.PICK_LOT_DATE
      //data.PICK_LOT_SEQ = this.params.PICK_LOT_SEQ
      //data.PICKING_LIST_NO = this.params.PICKING_LIST_NO_2
      this.DataIsSelected.push(data);
    }
    else {
      this.DataIsSelected.splice(this.DataIsSelected.indexOf(data), 1);
    }
    this.params.CNT_SEL = this.DataIsSelected.length;
  }


  ConfirmProcess() {
    if (this.params.LOCATION == "1") {
      this.selection.clear();
      this.DataIsSelected = [];
      this.tableData.forEach((row) => {
        if (row.LOCATION_NO) {
          if (row.LOCATION_NO.substring(0, 2).toUpperCase() >= this.params.LOCATION_FROM.substring(0, 2).toUpperCase() && row.LOCATION_NO.substring(0, 2).toUpperCase() <= this.params.LOCATION_TO.substring(0, 2).toUpperCase()) {
            this.DataIsSelected.push(row);
            this.selection.select(row)

          }
          this.params.CNT_SEL = this.DataIsSelected.length;
        }
      });
    }
    console.log(this.DataIsSelected)
    this.modal.confirm('Do you want to process and print picking cards?', this.viewref, this.Process)
  }

  Process = async () => {
    if (this.DataIsSelected.length > 0) {
      this.Http.get('SL', 'SNSE026M_GetPickLotSeq')
        .subscribe(res => {
          if (res.Table[0].PICK_LOT_SEQ) {
            this.params.PICK_LOT_SEQ = res.Table[0].PICK_LOT_SEQ
          }
          else {
            this.params.PICK_LOT_SEQ = 1;
          }

          this.Http.get('SL', 'SNSE026M_GetPickingNo')
            .subscribe(res => {
              this.params.PICKING_LIST_NO = res.Table[0].PICKING_LIST_NO

              this.DataIsSelected[0].PICK_LOT_DATE = this.params.PICK_LOT_DATE
              this.DataIsSelected[0].PICKING_LIST_NO = this.params.PICKING_LIST_NO;
              this.DataIsSelected[0].PICK_LOT_SEQ = this.params.PICK_LOT_SEQ;

              this.Http.post('SL', 'SNSE026M_Process', this.DataIsSelected)
                .subscribe(res => {
                  if (res.Table[0].STATUS == 'DONE') {
                    this.modal.info("Generate picking card completed!", this.viewref);
                    this.isProcessed = true;
                    if (this.params.AUTO_PRINT == 'Y') {
                      this.OpenReport()
                    }
                  }
                  else {
                    this.modal.warning("Generate picking card Fail!", this.viewref);
                  }
                })

            });

        });

    }
    else {
      this.modal.warning("NO DATA FOUND.", this.viewref);
    }
  };

  OpenReport() {
    this.Http.post('SL', 'SNSE026M_UpdateStatus', this.params)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.global.GoToReport("PMS_RPT_SALES_SNSE026R3_N",
            {
              P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
              P_IPADD: this.global.GetTokenDetail("ssIPAddress")
            });
          //this.Search();
          this.isProcessed = false;
          this.isPrinted = true;
        }
        else {
          this.modal.warning("Update Status Fail!", this.viewref);
        }
      })
  }

  CheckAutoPrint(event) {
    if (event.checked) {
      this.params.AUTO_PRINT = 'Y';
    }
    else {
      this.params.AUTO_PRINT = 'N';
    }
  }
}
