import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';


@Component({
  selector: 'snse031',
  templateUrl: './SNSE031.component.html',
  styleUrls: ['./SNSE031.component.css']
})



export class SNSE031Component implements OnInit {
  constructor(
    private Http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }



  public CustomerList: any;

  public tableData: any=[];
  public tableName: string;
  public dataSelected: any = [];
  public formData: any = {};  

  public params = {
    CUSTOMER_CODE: null,
    CUSTOMER_NAME: null,
    BRANCH_CODE: null,
    BRANCH_NAME: null,
  }

  ngOnInit() {

    this.tableName = "ReportConfigure";
  }


  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNSE025_N_GetCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }


  public SetSelectedCustomerCode(values: any) {
    this.params.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = values.CUSTOMER_NAME;

    this.params.BRANCH_CODE = values.BRANCH_CODE;
    this.params.BRANCH_NAME = values.BRANCH_NAME;

    this.Search();
  }

  Search = () => {
    this.tableData = null;
    this.Http.post('SL', 'SNSE031_GetData', this.params)
      .subscribe(res => {
        this.tableData = res.Table;
        if (this.tableData.length > 0) {
       
          this.tableData.forEach((e) => {           
            e.GROSS_WEIGHT = parseFloat(e.GROSS_WEIGHT).toFixed(3);       
            e.GROSS_MM = parseFloat(e.GROSS_MM).toFixed(3);   
          });
        } 
   
      })
  }


  ConfirmSave() {
    var err = 0;
    var empty = 0;
    var caseNo = '';
    this.tableData.forEach((e) => {
      if ((e.GROSS_MM != 0  ||  e.GROSS_WEIGHT != 0) && e.NET_WEIGHT > e.GROSS_WEIGHT) {
        err = 1;
        caseNo = caseNo + e.CASE_NO + ' ,';
      }
      if ((e.GROSS_MM > 0 || e.GROSS_WEIGHT > 0) && (e.GROSS_MM_OLD != e.GROSS_MM || e.GROSS_WEIGHT_OLD != e.GROSS_WEIGHT)) {
        empty = empty + 1;

      } 
    });

    if (err == 0 && empty == 1) {
      this.modal.confirm('Do you want to update on this data?', this.viewref, this.Save)
    }
    else if (err == 1) {
      this.modal.warning('Net Weight cannot over gross weight.', this.viewref)
    }
    else if (empty == 0) {
      this.modal.warning('There is no data change.', this.viewref)
    }
  }

  Save = () => {
    this.dataSelected = [];
    this.tableData.forEach((e) => {
      if ((e.GROSS_MM > 0 || e.GROSS_WEIGHT > 0) && (e.GROSS_MM_OLD != e.GROSS_MM || e.GROSS_WEIGHT_OLD != e.GROSS_WEIGHT))  {
        this.dataSelected.push(e);
      } 
    });

    this.Http.post('SL', 'SNSE031_Update', this.dataSelected)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info('Update data successfully.', this.viewref);
          this.Search();
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      })
  }

  grossChange(data) {
    data.GROSS_WEIGHT = parseFloat(data.GROSS_WEIGHT).toFixed(3);
  };

  grossMMChange(data) {
    data.GROSS_MM = parseFloat(data.GROSS_MM).toFixed(3);
  }
}
