import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';
import { SelectionModel } from '@angular/cdk/collections';

@Component({
  selector: 'snse073',
  templateUrl: './SNSE073.component.html',
  styleUrls: ['./SNSE073.component.css']
})



export class SNSE073Component implements OnInit {


  constructor(
    private Http: HttpService,
    private router: Router,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  public selection = new SelectionModel<any>(true, []);
  public selection2 = new SelectionModel<any>(true, []);

  public params: any = {}
  public tableData: any = [];
  public numLocal: any;
  public numExport: any;
  public IsSearch: boolean = true;

  ngOnInit() {
    this.params.CURRENT_DATE = new Date();
    this.params.VT_J = 60;
    this.params.VT_K = 60;
    this.params.VT_L = 60;
    this.params.VT_O = 60;
  }

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNSE073_GetCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public lookupOrderNoConfig: any = {
    ColName: "LOOKUP_ORDER_NO",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE073_GetOrderNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public lookupOrderPartNoConfig: any = {
    ColName: "LOOKUP_ORDER_PART_NO",
    PlaceholderText: "Select Order Part No",
    SourceController: "SL",
    SourceMethodName: "SNSE073_GetOrderPartNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public SetSelectedCustomerCode(values: any) {
    this.params.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = values.CUSTOMER_NAME;
  }

  public SetSelectedOrderNo(value: any) {
    this.params.ORDER_NO = value.ORDER_NO;
    this.params.FIRST_ALLOCATE = value.FIRST_ALLOCATE
    this.params.LAST_UPD_DATE = value.LAST_UPD_DATE
    this.params.LAST_UPD_NAME = value.LAST_UPD_NAME
  }

  public SetSelectedOrderPartNo(value: any) {
    this.params.ORDER_PART_NO = value.PART_NO;
  }


  Search = () => {
    this.tableData = [];
    this.Http.post('SL', 'SNSE073_getData', this.params)
      .subscribe(res => {
        this.tableData = res.Table;
        this.numExport = 0;
        this.numLocal = 0;
        if (this.tableData.length > 0) {
          this.selection.clear()
          this.selection2.clear()
          //this.params.LAST_UPD_NAME = this.tableData[0].LAST_UPD_NAME
          //this.params.LAST_UPD_DATE = this.tableData[0].LAST_UPD_DATE
          this.tableData.forEach((e) => {
            if (e.VENDOR_TYPE == 'K' || e.VENDOR_TYPE == 'J') {
              this.numExport = this.numExport + 1;
              if (e.CHK == 'Y') {
                this.selection2.select(e)
              }
            }
            else {
              this.numLocal = this.numLocal + 1;
              if (e.CHK == 'Y') {
                this.selection.select(e)
              }
            }
          });
        }
      })
  }

  ConfirmSave() {
    this.modal.confirm('Do you want to save on this data?', this.viewref, this.Save)
  }

  Save = () => {

    // track row/part error
    this.Http.post('SL', 'SNSE073_Save', this.tableData)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info("Update Data Completed.", this.viewref);
          this.Search();
        }
        else {
          this.modal.warning("UpdateOrder Failed!", this.viewref);
        }
      })
  }

  isAllSelectedLocal() {
    const numSelected = this.selection.selected.length;
    const numRows = this.numLocal;
    return numSelected === numRows;
  }

  ToggleLocal(event) {
    if (event.checked == false) {
      this.selection.clear()
      this.tableData.map(x => {
        if ((x.VENDOR_TYPE == 'L' || x.VENDOR_TYPE == 'O') && x.OVER_DUE > 0) {
          x.CHK = null;
        }
      })
    } else {
      this.tableData.forEach(row => {
        if ((row.VENDOR_TYPE == 'L' || row.VENDOR_TYPE == 'O') && row.OVER_DUE > 0) {
          this.selection.select(row)
          row.CHK = 'Y';
        }
      });
    }
  }

  isAllSelectedExport() {
    const numSelected = this.selection2.selected.length;
    const numRows = this.numExport;
    return numSelected === numRows;
  }

  ToggleExport(event) {
    if (event.checked == false) {
      this.selection2.clear()
      this.tableData.map(x => {
        if ((x.VENDOR_TYPE == 'J' || x.VENDOR_TYPE == 'K') && x.OVER_DUE > 0) {
          x.CHK = null;
        }
      })
    } else {
      this.tableData.forEach(row => {
        if ((row.VENDOR_TYPE == 'J' || row.VENDOR_TYPE == 'K') && row.OVER_DUE > 0) {
          this.selection2.select(row)
          row.CHK = 'Y';
        }
      });
    }
  }

  CheckboxChange(event, data) {
    if (event.checked) {
      data.CHK = 'Y';
    }
    else {
      data.CHK = null;
    }
  }

  ClickNew() {
    this.IsSearch = false;
  }
}
