import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';
import * as cloneDeep from 'lodash/cloneDeep';
import { Globals } from '../../../core/global';

@Component({
  selector: 'snm039p',
  templateUrl: './SNM039P.component.html',
  styleUrls: ['./SNM039P.component.css']
})

export class SNM039PComponent implements OnInit {

  constructor(
    private http: HttpService,
    private global: Globals,
    private router: Router,
    private modal : ModalService,
    private viewref : ViewContainerRef
  ) { }

  @ViewChild("dialog", { static: false }) dialog: any;
  @ViewChild("DialogAdd", { static: false }) DialogAdd: any;
  @ViewChild("DialogEdit", { static: false }) DialogEdit: any;

  public tabledata = [];
  public paramAdd: any = {};
  public paramEdit: any = {};
  public paramSearch: any = {};
  public classNameEdit: any;
  public isAdd: boolean = false;

  public hideCols: Array<string> = [];
  DescriptCodeControl = new FormControl('', [Validators.required])

  public ConfigSalesClass: any = {
    ColName: "SALES_CLASS",
    ColValue: "",
    PlaceholderText: "Select Sales Class",
    SourceController: "TI",
    SourceMethodName: "SNM039P_Sales_Class",
    NoOfShowRecords: 20,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSalesClass(values: any) {
    this.paramSearch.SALES_CLASS = values.SALES_CLASS;
    this.paramSearch.CLASS_NAME = values.CLASS_NAME;
    this.paramSearch.LAST_UPD_BY = values.LAST_UPD_BY;
    this.paramSearch.LAST_UPD_DATE = values.LAST_UPD_DATE;
  }


  public Search() {
    this.tabledata = [];
    this.http.post("TI", "SNM039P_getSearch", this.paramSearch)
      .subscribe(res => {
        this.tabledata = res.Table;
      })
  }

  public EditRow(data) {
    this.DescriptCodeControl.reset();
    this.isAdd = false;
    this.paramEdit = data;
    this.DialogEdit.OpenDialog();
  }

  public Save() {
    this.modal.confirm("Do you want to save your change?", this.viewref,
      () => {
        this.http.post('TI', 'SNM039P_Save_Class_Name', this.paramEdit)
          .subscribe(res => {
            if (res.Table[0].STATUS === "Done") {
              this.modal.info('Save successfully', this.viewref)
              this.Search();
              this.DialogEdit.Close();
            }
          }, (err) => {
            console.log(err, 'err')
          })
      }, () => { })
  }

  public CancelEdit() {
    this.DialogEdit.Close();
  }

  public Add() {
    this.DescriptCodeControl.reset();
    //this.ParamAdd = {};
    //this.isAdd = true
    this.DialogAdd.OpenDialog();
  }

  public SaveAdd() {
    this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmSave);
  }

  public ConfirmSave = () => {
    console.log(this.paramAdd)
    this.http.post('TI', 'SNM039P_Insert', this.paramAdd)
      .subscribe(res => {
     
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
          this.paramAdd = this.global.ClearObject(this.paramAdd);
          this.DialogAdd.Close();

        } else if (res.Table[0].STATUS == 'Duplicate') {
          this.modal.warning('No change to save. Found duplicate record.', this.viewref);
        }
        else {
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }

      })
  }

  public CancelAdd() {
    this.DialogAdd.Close();
  }

  public Delete(data) {
    this.modal.confirm("Do you want to delete record?", this.viewref, () => this.ConfirmDelete(data))
  }

  public ConfirmDelete = data =>  {

    this.http.post('TI', 'SNM039P_Delete', data)
      .subscribe(res => {
        console.log(res);
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info('Delete completed: 1 record', this.viewref);
          this.Search();
        }
        else if (res.Table[0].STATUS == 'FAIL')  {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      })

  }

  ngOnInit() {

  }
}
