import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';

enum Response {
  No = 1,
  Yes  ,
}


@Component({
  selector: 'SNM033',
  templateUrl: './SNM033.component.html',
  styleUrls: ['./SNM033.component.css'],
})


export class SNM033Component implements OnInit {

  constructor(
    private http: HttpService,
    private router: Router,
    private global : Globals,
    private modal : ModalService,
    private viewref : ViewContainerRef
  ) { }

  @ViewChild("dialogEdit",{static : false}) dialogEdit;
  @ViewChild("dialogEditPart",{static : false}) dialogEditPart;


  public CustomerList: any;
  private loaded: boolean = false;
  public opened: boolean;

  public tableData: any = [];
  public tableData2: any = [];
  public tableData3: any = [];

  public tableName: string;
  public show: boolean = true;



public ConfigLocation: any = {
  ColName: "LOCATION_NO",
  ColValue: "LOCATION_NO",
  PlaceholderText: "Select Location",
  SourceController: "wPMS",
  SourceMethodName: "GetLocation",
  NoOfShowRecords: 30,
  MinLengthSearch: 3,
  UpperCase : true
}


public ConfigRackCode: any = {
  ColName: "RACK_CODE",
  ColValue: "RACK_CODE",
  PlaceholderText: "Select Rack Code",
  SourceController: "wPMS",
  SourceMethodName: "GetRackCode",
  NoOfShowRecords: 30,
  MinLengthSearch: 1,
}

public ConfigRackGroupCode: any = {
  ColName: "RACK_GROUP_CODE",
  ColValue: "RACK_GROUP_CODE",
  PlaceholderText: "Select Rack Group Code",
  SourceController: "wPMS",
  SourceMethodName: "GetRackGroupCode",
  NoOfShowRecords: 30,
  MinLengthSearch: 0
}

public PartNoLookupConfig: any = {
  ColName: "LOOKUP_PART_NAME",
  PlaceholderText: "Select Part No.",
  SourceController: "wPMS",
  SourceMethodName: "GetPartNo",
  NoOfShowRecords: 30
  // SourceParams: {
  //     VENDOR_CODE: this.VendorCode
  // }
}

public ConfigLockLocation: any = {
  ColName: "LOCK_LOCATION",
  ColValue: "LOCK_LOCATION",
  PlaceholderText: "Select Lock Location",
  SourceController: "WH",
  SourceMethodName: "GetLockLocation",
  NoOfShowRecords: 30,
  MinLengthSearch: 0
}

public CategoryList :any = [];


public params = {
  LOCATION_NO : null,
  PART_NO : null,
  RACK_CODE : null,
  RACK_GROUP_CODE : null,
  SHOW_RECORD : 1000000
}


public EditData = {
  LOCATION_NO : null,
  PART_NO : null,
  RACK_CODE : null,
  RACK_GROUP_CODE : null,
  SHOW_RECORD : 1000000,
  DIMENSION_MAX: null,
  DIMENSION_MID:null,
  DIMENSION_MIN: null,
  SEQUENCE_NO : null,
  LOCK_LOCATION : null,
  LAST_UPD_BY : null,
  LAST_UPD_DATE : null
}

public EditDataPart = {
  PART_NO : null,
  LOCATION_NO : null,
  DIMENSION_MAX : null,
  DIMENSION_MID : null,
  DIMENSION_MIN : null,
  PART_NAME : null,
  LAST_UPD_BY : null,
  LAST_UPD_DATE : null
}


  

  ngOnInit() {

    this.GetCat();
  }

  GetCat() {
    this.http.get('WH', 'SNM026P_GetPartCategory')
        .subscribe(res => {
            this.CategoryList = res.Table
        })
  }

  AddRecord(){
    this.tableData.push({
      LOCATION_NO: '',
        PART_NO: '',
        DIMENSION_MAX: '',
        DIMENSION_MID: '',
        DIMENSION_MIN: '',
        OH_QTY: '',
        INDENT_QTY: '',
        RACK_CODE: '',
        RACK_GROUP_CODE: '',
        SEQUENCE_NO: '',
        PART_CATEGORY: '',
        LOCK_LOCATION: '',
    })

   this.tableData =  this.tableData.slice();
  }

  Search(){
    this.tableData = [];


    if(!this.params.LOCATION_NO && !this.params.PART_NO && !this.params.RACK_CODE && !this.params.RACK_GROUP_CODE){
      this.params.SHOW_RECORD = 1000;
    }


    this.http.post("WH","SNM033_GetData",this.params)
    .subscribe(res =>{
      this.tableData = res.Table
    })
  }


  Edit(data){
    this.EditData.LOCATION_NO = data.LOCATION_NO
    this.EditData.PART_NO = data.PART_NO
    this.EditData.DIMENSION_MAX = data.DIMENSION_MAX
    this.EditData.DIMENSION_MID = data.DIMENSION_MID
    this.EditData.DIMENSION_MIN = data.DIMENSION_MIN
    this.EditData.RACK_CODE = data.RACK_CODE
    this.EditData.RACK_GROUP_CODE = data.RACK_GROUP_CODE
    this.EditData.SEQUENCE_NO = data.SEQUENCE_NO
    this.EditData.LOCK_LOCATION = data.LOCK_LOCATION
    this.EditData.LAST_UPD_BY = data.LAST_UPD_BY
    this.EditData.LAST_UPD_DATE = data.LAST_UPD_DATE
    this.dialogEdit.colors = "#c3002f"
    this.dialogEdit.title = "Location No :" + ' ' + data.LOCATION_NO
    this.dialogEdit.OpenDialog();
  }

  SaveEdit(){
    this.modal.confirm("Do you want to save changed you have made?",this.viewref,this.ConfirmSave)
  }

  ConfirmSave = () => {
      this.http.post("WH","SNM033_Save",this.EditData)
      .subscribe(res =>{
        if(res.Table[0].STATUS == "Done"){
          this.modal.info("Transaction complete: applied and saved.",this.viewref)
          this.Search();
          this.dialogEdit.Close();
        }else{
          this.modal.warning("No change to save. Something went wrong.",this.viewref)
        }
      })
  }

  CancelEdit(){
    this.dialogEdit.Close();
  }

  ClickRow(event){
    this.EditData.PART_NO = event.PART_NO;
  }

  SelectedTab(event){
    if(this.EditData.PART_NO && event.index == 2){
      this.GetPartDetail()
    }
    
  }


  GetPartDetail(){
    //this.tableData3 = [];
    this.http.get("WH","GetPartDetail",this.EditData.PART_NO)
    .subscribe(res =>{
      
      this.tableData3 = res.Table
      
    })
  }


  EditPart(data){

    this.EditDataPart.PART_NO = data.PART_NO
    this.EditDataPart.PART_NAME = data.PART_NAME_TH 
    this.EditDataPart.LOCATION_NO = data.LOCATION_NO
    this.EditDataPart.DIMENSION_MAX = data.DIMENSION_MAX
    this.EditDataPart.DIMENSION_MID = data.DIMENSION_MID
    this.EditDataPart.DIMENSION_MIN = data.DIMENSION_MIN
    this.EditDataPart.LAST_UPD_BY = data.LAST_UPD_BY
    this.EditDataPart.LAST_UPD_DATE = data.LAST_UPD_DATE
    this.dialogEditPart.title = "Edit Part";
    this.dialogEditPart.OpenDialog();
  }


  SaveEditPart(){
    this.modal.confirm("Do you want to save changed you have made?",this.viewref,this.ConfirmSavePart)
  }

  ConfirmSavePart = () => {
      this.http.post("WH","SNM033_SavePart",this.EditDataPart)
      .subscribe(res =>{
        if(res.Table[0].STATUS == "Done"){
          this.modal.info("Transaction complete: applied and saved.",this.viewref)
          this.GetPartDetail();
          this.dialogEditPart.Close();
        }else{
          this.modal.warning("No change to save. Something went wrong.",this.viewref)
        }
      })
  }

  CancelEditPart(){
    this.dialogEditPart.Close();
  }


}
