import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from '../../../core/global';
import { retry } from 'rxjs/operators';


@Component({
  selector: 'snse052',
  templateUrl: './SNSE052.component.html',
  styleUrls: ['./SNSE052.component.css']
})

export class SNSE052Component implements OnInit {

  constructor(
    private HttpService: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private route: ActivatedRoute,
    private global: Globals
  ) { }
  
  public ListDataReportCondition: any = {
    CUSTOMER_CODE : null,//Step 1
    CUSTOMER_NAME : null,
    ORDER_NO : null,//Step 2
    ORDER_DATE : null,
    ORDER_CLASS : null,
    SELECT : null
  };

  public CHB_SELECT:string = "Select";
  public CHB_ALL:string = "All"; 

  public CheckBoxAutoPrint : Boolean = false;

  public RowPackingCard: any ={
    pIP : null,
    pAUTO_PRINT : null,
    pSELECT : null,
    COMPANY_CODE : null,
    CUSTOMER_CODE : null,
    ORDER_NO : null,
    ITEM_NO : null,
    SUB_ITEM_NO : null,
    INSTRUCTION_NO : null
  }

  public dataListDocNo: any = [];

  // public ConfigCustomer: any = {
  //   ColName: "LOOKUP_CUSTOMER",
  //   ColValue: "CUSTOMER_CODE",
  //   PlaceholderText: "Select Customer Code",
  //   SourceController: "WH",
  //   SourceMethodName: "SNSE052_FindCustomer",
  //   NoOfShowRecords: 100,
  //   MinLengthSearch: 1,
  //   UpperCase: true
  // }

  //Used config by fix ColValue is string emply that callback function will change event type return(this case is ObjectList);
  //if defind ColValue is Name of Columns, will return key value.
  public ConfigCustomer: any = {
    ColName: "LOOKUP_CUSTOMER",
    ColValue: "",
    PlaceholderText: "Select Customer Code",
    SourceController: "WH",
    SourceMethodName: "SNSE052_FindCustomer",
    NoOfShowRecords: 100,
    MinLengthSearch: 1,
    UpperCase: true
  }

  public CustomerList: any;
  public tableData: any;
  public headerList: Array<any> = [];
  public dataList: any;
  public displayedColumns: string[] = [];
  public isCustomContent: boolean = false;

  public totalItem = 0;
  public totalSelect = 0;

  ngOnInit() {
        this.ListDataReportCondition.SELECT = this.CHB_SELECT;
        
        this.CheckBoxAutoPrint = false;
        //this.getTableHeader();
  }

 
  public fillOrder(strCustomer:any){
    console.log("ListData CustInfo: ",strCustomer);
    this.fillListOrder(strCustomer);
  }

  public callBack(event:any){
    this.ListDataReportCondition.CUSTOMER_CODE = event.CUSTOMER_CODE;
    this.ListDataReportCondition.CUSTOMER_NAME = event.CUST_NAME_TH;
    this.fillListOrder(this.ListDataReportCondition.CUSTOMER_CODE); 
  }    

  public clearOrder(){

    this.ListDataReportCondition.ORDER_NO = null;
    this.ListDataReportCondition.ORDER_DATE = null;
    this.ListDataReportCondition.ORDER_CLASS = null;

    this.dataListDocNo = null;

    //Table
  }

  public fillListOrder(strCust: string){
      this.clearOrder();
      if (!!strCust) {
          // console.log("Data strCustBrach", strCust);
          this.HttpService.get("WH", "SNSE052_DocumentByCustomer", strCust || "null")
          .subscribe(result => {
            // console.log("list data DocNo: ",result);
            if(result.Table.length > 0 ){
              this.dataListDocNo = result.Table;    
            }            
          }, err => {
              this.modal.error(err.message, this.viewref);
          });
      } else {
          alert('Please input customer code and branch code');
      }
  }

  public radioChange(event: any){
    console.log(this.ListDataReportCondition.SELECT);
    console.log("Auto:",this.CheckBoxAutoPrint);
  }

  public docNoSelectChange(event: any){
    let target = event.source.selected._element.nativeElement;
    let selectedData = {
      value: event.value,
      text: target.innerText.trim(),
      id: event.id
    };
        
    // console.log(this.dataListDocNo);
    for(let item of this.dataListDocNo){
        //console.log(item.ORDER_NO+" : "+item.ORDER_DATE);
        let strKey = item.ORDER_NO+" : "+item.ORDER_DATE;
        if(strKey = selectedData.text)
        {
          this.ListDataReportCondition.ORDER_DATE = item.ORDER_DATE;
          this.ListDataReportCondition.ORDER_CLASS = item.ORDER_CLASS;
        }
    }
  }
 
  checkSearchCondition():Boolean {
    //Check null,undefined,""
    if (this.ListDataReportCondition.CUSTOMER_CODE === null || this.ListDataReportCondition.CUSTOMER_CODE === undefined) {
      //this.ListDataReportCondition.CUSTOMER_CODE = "null";
      return false;
    }

    if (this.ListDataReportCondition.ORDER_NO === null || this.ListDataReportCondition.ORDER_NO === undefined) {
      this.ListDataReportCondition.ORDER_NO = "null";
    }
    return true;
  }//end checkSearchCondition

  public searchData(){
      if(!this.checkSearchCondition()){
        console.log("No search");
        return false;
      }

      this.dataList = [];
      // this.oldDataList = [];
      
      
      //console.log("Show search criteria");
      //console.log(this.ListDataReportCondition);
      
      this.HttpService.post("WH", "SNSE052_SearchData", JSON.stringify(this.ListDataReportCondition))
      .subscribe(result => {
          //console.log(result);
          //add seq no.
          let i = 1;
          result.Table.forEach(d => {
            d.SEQ_NO = i;
            this.totalItem = i;
            i++;
          });//end add seq

          this.dataList = result.Table;
          //console.table(this.dataList);

      }, (err) => { this.modal.error(err.message, this.viewref); })
  }

  public checkboxChange(evt, ctrl) {
      ctrl.SEND_DATA_FLAG = evt.checked ? 'Y' : 'N';

      if (evt.checked) {
        this.totalSelect++;
      } else {
        this.totalSelect--;
      }
  }

  public print(){
    this.savePackingPack();
  }

  clearRow(){
      this.RowPackingCard.pIP = null;
      this.RowPackingCard.pAUTO_PRINT = null;
      this.RowPackingCard.pSELECT = null;
      this.RowPackingCard.COMPANY_CODE = null;
      this.RowPackingCard.CUSTOMER_CODE = null;
      this.RowPackingCard.ORDER_NO = null;
      this.RowPackingCard.ITEM_NO = null;
      this.RowPackingCard.SUB_ITEM_NO = null;
      this.RowPackingCard.INSTRUCTION_NO = null;
  }

  savePackingPack(){
      if(this.dataList.length > 0){
            // console.log("Show dataList:",this.dataList);
            //console.log(this.dataList );

            //**Clear Old data select in temp table before insert new select
            this.clearRow();
            this.RowPackingCard.pIP = this.global.GetTokenDetail("ssIPAddress");//(BackEnd had IPAddress) Get here because when open report will used this fuction to get IP
            this.HttpService.post("WH", "SNSE052_ClearOldData", JSON.stringify(this.RowPackingCard))
              .subscribe(result => {
                    //Check Save sussessed.
                    //this.dataList = result.Table;
                    console.log(result);
              }, (err) => { this.modal.error(err.message, this.viewref); });

            if(this.ListDataReportCondition.SELECT == this.CHB_SELECT){
                this.dataList.forEach(element => {
                      if(element.SEND_DATA_FLAG.trim() == 'Y'){
                          this.RowPackingCard.pIP = this.global.GetTokenDetail("ssIPAddress");//(BackEnd had IPAddress) Get here because when open report will used this fuction to get IP
                          this.RowPackingCard.pAUTO_PRINT = this.CheckBoxAutoPrint ? 'Y' : 'N' ;
                          this.RowPackingCard.pSELECT = element.SEND_DATA_FLAG;
                          this.RowPackingCard.COMPANY_CODE = element.COMPANY_CODE ;
                          this.RowPackingCard.CUSTOMER_CODE = element.CUSTOMER_CODE;
                          this.RowPackingCard.ORDER_NO = element.ORDER_NO;
                          this.RowPackingCard.ITEM_NO = element.ITEM ;
                          this.RowPackingCard.SUB_ITEM_NO = element.SUB_ITEM_NO;
                          this.RowPackingCard.INSTRUCTION_NO = element.INSTRUCTION_NO;

                          //insert to BackEnd
                          //console.table(this.RowPackingCard );
                          this.HttpService.post("WH", "SNSE052_SaveRowSelect", JSON.stringify(this.RowPackingCard))
                          .subscribe(result => {
                              //Check Save sussessed.
                              //this.dataList = result.Table;
                              console.log(result);
                          }, (err) => { this.modal.error(err.message, this.viewref); });

                      }//end 'Y'
                });//end forEach

                this.GoToReportPrintCheckList();

            }else{
                  //send all to BackEnd
                  this.clearRow();
                  this.RowPackingCard.pIP = this.global.GetTokenDetail("ssIPAddress");//(BackEnd had IPAddress) Get here because when open report will used this fuction to get IP
                  this.RowPackingCard.pAUTO_PRINT = this.CheckBoxAutoPrint ? 'Y' : 'N' ;
                  this.RowPackingCard.pSELECT = "null";
                  this.RowPackingCard.COMPANY_CODE = this.global.GetTokenDetail("ssComCode");
                  this.RowPackingCard.CUSTOMER_CODE = this.ListDataReportCondition.CUSTOMER_CODE;
                  this.RowPackingCard.ORDER_NO = this.ListDataReportCondition.ORDER_NO;

                  this.HttpService.post("WH", "SNSE052_SaveAllRow", JSON.stringify(this.RowPackingCard))
                  .subscribe(result => {
                        //Check Save sussessed.
                        //this.dataList = result.Table;
                        console.log(result);
                        this.GoToReportPrintCheckList();
                  }, (err) => { this.modal.error(err.message, this.viewref); });
            }

      }//end if

  }

  GoToReportPrintCheckList(){
    // this.global.GoToReport("PMS_RPT_IC_SNSQ088", {  P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"), 
    //                                                 P_USER_ID: this.global.GetTokenDetail("ssUserName")  
    // })
  }


}
