import { Component, OnInit, ViewContainerRef, ElementRef, ViewChild } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { tap } from 'rxjs/operators';
import { Globals } from 'src/app/core/global';
import { AutoCompleteQueryComponent } from 'src/app/components/shared/auto-complete-query/auto-complete-query.component';
import * as moment from 'moment';

@Component({
  selector: 'app-snpe036',
  templateUrl: './snpe036.component.html',
  styleUrls: ['./snpe036.component.css']
})
export class SNPE036Component implements OnInit {
  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private el: ElementRef,
    private global: Globals
  ) { }

  @ViewChild("dialog", { static: true }) dialog: any;
  @ViewChild("autoCompleteVendor", { static: true }) autoCompleteVendor: AutoCompleteQueryComponent;

  private currentDate: moment.Moment = moment();
  public tableHeader: any = {};
  public DocNo: string;
  public DocDate: moment.Moment;
  public Vendor: string;
  public VendorCode: string;
  public InvoiceNo: string;
  public InvoiceDate: moment.Moment;
  public DeliveryDate: moment.Moment;
  public InvoiceStatus: string;
  public InvoiceProcess: string;
  public Invoice: any = {};
  public UpdateBy: string;
  public UpdateDate: moment.Moment;

  public TableData: Array<any> = [];
  public MatchedPO: Array<any> = [];
  public ParamsSearch: any = {
    DOCUMENT_DATE: moment()
  };
  public ShowList: boolean = true;
  public DocList: Array<any> = [];
  public tempData: any = {};
  public IsCancel : boolean = false;
  public ConfirmDate : any;
  public vendorLookupConfig: any = {
    ColName: "LOOKUP_VENDOR_NAME",
    PlaceholderText: "Select Vendor",
    SourceController: "AC",
    SourceMethodName: "SNPE036_GetVendorCode",
    NoOfShowRecords: 50,
    UpperCase: true
  }

  public PartNoLookupConfig: any = {
    ColName: "LOOKUP_PART_NAME",
    PlaceholderText: "Select Part No.",
    SourceController: "wPMS",
    SourceMethodName: "GetPartNo",
    NoOfShowRecords: 20
  }

  public ConfigDocNo: any = {
    ColName: "DOCUMENT_NO",
    PlaceholderText: "Select Document No.",
    SourceController: "AC",
    SourceMethodName: "SNPE036_GetDocList",
    NoOfShowRecords: 50,
    MinLengthSearch: 2,
    UpperCase: true
  }

  
  public ConfigInvoiceNo: any = {
    ColName: "REF_INV_NO",
    PlaceholderText: "Select Document No.",
    SourceController: "AC",
    SourceMethodName: "SNPE036_GetInvList",
    NoOfShowRecords: 50,
    MinLengthSearch: 2
  }
  ngOnInit() {
  }

  GetDate() {
    return this.http.GetSystemDate()
      .pipe(tap((result: any) => {
        if (result) this.currentDate = result;
      }))
  }

  Search() {
    this.http.get("AC", "SNPE036_GetDocumentList",
      this.global.EscapeCharacter(this.ParamsSearch.DOCUMENT_NO) || 'NULL',
      this.global.ConvertDateToFormatSTD(this.ParamsSearch.DOCUMENT_DATE) || 'NULL',
      this.global.EscapeCharacter(this.ParamsSearch.INVOICE_NO) || 'NULL',
      this.global.ConvertDateToFormatSTD(this.ParamsSearch.INVOICE_DATE) || 'NULL')
      .subscribe(result => {
        this.DocList = result.Table;
      })
  }

  ViewClick(data) {
    console.log('dd', data)
    this.DocNo = data.DOCUMENT_NO;
    this.DocDate = data.DOCUMENT_DATE;
    this.InvoiceNo = data.REF_INV_NO;
    this.InvoiceStatus = data.INVOICE_STATUS;
    this.InvoiceProcess = '';
    this.InvoiceDate = data.REF_INV_DATE;
    this.DeliveryDate = data.BL_AWB_DATE

    this.Vendor = data.VENDOR;
    this.VendorCode = data.VENDOR_CODE;
    this.UpdateBy = null;
    this.UpdateDate = null;

    this.TableData = [];
    this.MatchedPO = [];
    this.ShowList = false;

    this.GetDocumentDetail();
  }

  AddClick() {
    this.DocNo = null;
    this.DocDate = this.currentDate;
    this.InvoiceNo = null;
    this.InvoiceStatus = "New";
    this.InvoiceProcess = 'N';
    this.InvoiceDate = this.currentDate;
    this.DeliveryDate = this.currentDate;

    this.Vendor = null;
    this.VendorCode = null;
    this.UpdateBy = null;
    this.UpdateDate = null;

    this.TableData = [];
    this.MatchedPO = [];
    this.ShowList = false;
    this.tempData = {};
    this.tableHeader = {};
    this.tableHeader.EXP_CLEANRANCE_AMT_B = 0;
    this.tableHeader.EXP_OTHER_AMT_B = 0;
    this.CreateDetailRow(0);
  }

  // NewDocument() {
  //   this.modal.confirm("Are you sure to new document?<br>All changes will be cleared.", this.viewref
  //     , () => {
  //       this.ngOnInit();
  //     }, () => { })
  // }

  SaveDocument() {
    let saveRows = this.TableData.filter((d, i) => {
      d.DOCUMENT_NO = this.DocNo;
      d.VENDOR_CODE = this.VendorCode;
      d.INVOICE_NO = this.InvoiceNo;
      d.INVOICE_DATE = this.global.ConvertDateToFormatSTD(this.InvoiceDate);
      d.BL_AWB_DATE = this.global.ConvertDateToFormatSTD(this.DeliveryDate);
      //d.TOTAL_EXP_CLEANRANCE_AMT_B = this.tableHeader.EXP_CLEANRANCE_AMT_B;
      //d.TOTAL_EXP_OTHER_AMT_B = this.tableHeader.EXP_OTHER_AMT_B;
      //d.TOTAL_INCOME_TAX = this.TotalDuty();

      return this.CheckRequiredFields(i, false) && d.INVOICE_PROCESS === 'N';
    })

    if (saveRows.length > 0) {
      this.modal.confirm("Are you sure to confirm?", this.viewref
        , () => {
          this.http.post("AC", ["SNPE036_SaveDocument", this.VendorCode, this.global.EscapeCharacter(this.InvoiceNo), this.DocNo], saveRows)
            .subscribe(result => {
              // this.modal.info("Document saved successfully.", this.viewref);
              this.DocNo = result.DOCUMENT_NO;
              this.ToShelve();
              // this.CheckDocument();
            }, err => {
              this.modal.error(err.message, this.viewref);
            })
        }, () => { })
    } else {
      this.modal.error("Unable to process.", this.viewref);
    }
  }

  DeleteDocument() {
    this.modal.confirm("Are you sure to cancel this document?", this.viewref
      , () => {
        this.http.post("AC", ["SNPE036_DeleteDocument", this.VendorCode, this.global.EscapeCharacter(this.InvoiceNo), this.DocNo], {})
          .subscribe(result => {
            if (result === "Done") {
              this.modal.info("Transaction complete: applied and saved.", this.viewref);
              this.IsCancel = true;
              this.ngOnInit();
            }
          }, err => {
            this.modal.error(err.message, this.viewref);
          })
      }, () => {

      });
  }

  ToShelve() {
    // this.modal.confirm("Confirm for to shelve this RD?", this.viewref
    //   , () => {
    //console.log()
    this.http.post("AC", ["SNPE036_ToShelve", this.DocNo], {})
      .subscribe(result => {
        if (result === "Done") {
          this.modal.info("Transaction complete: applied and saved.", this.viewref);
          this.CheckDocument();
        }
      })
    // }, () => { })
  }

  GetDocumentDetail() {
    if (this.VendorCode && this.InvoiceNo && this.DocNo) {
      this.http.get("AC", "SNPE036_CheckDocument", this.DocNo)
        .subscribe(result => {
          if (result.Table.length > 0) {
            this.tableHeader = result.Table[0];

            this.VendorCode = this.tableHeader.VENDOR_CODE;

            this.DocNo = this.tableHeader.DOCUMENT_NO;
            this.DocDate = this.tableHeader.DOCUMENT_DATE;
            this.InvoiceNo = this.tableHeader.INVOICE_NO;
            this.InvoiceDate = this.tableHeader.INVOICE_DATE;
            this.DeliveryDate = this.tableHeader.BL_AWB_DATE;
            this.InvoiceStatus = this.tableHeader.INVOICE_STATUS;
            this.InvoiceProcess = this.tableHeader.INVOICE_PROCESS;
            this.UpdateBy = this.tableHeader.LAST_UPD_BY;
            this.UpdateDate = this.tableHeader.LAST_UPD_DATE;
            this.ConfirmDate = this.tableHeader.CONFIRM_DATE;
            this.TableData = result.Table1;
            console.log('this.TableData',this.TableData)
          
          }
        })
    }
  }
  
  CheckDocument() {
    if (this.VendorCode && this.InvoiceNo) {
      this.http.get("AC", "SNPE036_CheckDocument", this.VendorCode, this.global.EscapeCharacter(this.InvoiceNo))
        .subscribe(result => {
          if (result.Table.length > 0) {
            this.tableHeader = result.Table[0];

            this.VendorCode = this.tableHeader.VENDOR_CODE;

            this.DocNo = this.tableHeader.DOCUMENT_NO;
            this.DocDate = this.tableHeader.DOCUMENT_DATE;
            this.InvoiceNo = this.tableHeader.INVOICE_NO;
            this.InvoiceDate = this.tableHeader.INVOICE_DATE;
            this.DeliveryDate = this.tableHeader.BL_AWB_DATE;
            this.InvoiceStatus = this.tableHeader.INVOICE_STATUS;
            this.InvoiceProcess = this.tableHeader.INVOICE_PROCESS;
            this.UpdateBy = this.tableHeader.LAST_UPD_BY;
            this.UpdateDate = this.tableHeader.LAST_UPD_DATE;
            this.ConfirmDate = this.tableHeader.CONFIRM_DATE;
            this.TableData = result.Table1;
          }
        })
    }
  }

  CheckDeleteButton() {
    return this.InvoiceProcess === 'C'
      && this.TableData.find(d => d.STATUS_CODE == '55');
  }

  CheckValidSave() {
    // return true;
    return this.TableData.find((d, i) => this.CheckRequiredFields(i, false) && d.INVOICE_PROCESS === 'N');
  }

  CheckRequiredFields(tblIndex, allowUnChange: boolean = true) {
    let valid: boolean = (this.VendorCode && this.InvoiceNo && this.InvoiceDate && this.DeliveryDate) ? true : false;

    if (valid) {
      let thisRow = this.TableData[tblIndex];
      let countChangeItems: number = 0;

      if (thisRow.ACCEPT_PART_NO) countChangeItems++;
      if (thisRow.ITEM_QTY) countChangeItems++;
      if (thisRow.ACCEPT_PART_NO) countChangeItems++;

      valid = (countChangeItems > 0 && thisRow.ACCEPT_PART_NO && thisRow.ITEM_QTY && thisRow.UNIT_PRICE_B) || (allowUnChange && countChangeItems === 0) ? true : false;
    }

    return valid;
  }

  CheckActiveRow(tblIndex) {
    let valid: boolean = (this.VendorCode && this.InvoiceNo && this.InvoiceDate && this.DeliveryDate) ? true : false;

    if (valid) {
      valid = (!this.TableData[tblIndex].INVOICE_PROCESS || this.TableData[tblIndex].INVOICE_PROCESS === 'N') && !this.DocNo;
    }

    if (valid && tblIndex > 0) {
      let prevRow = this.TableData[tblIndex - 1];

      valid = (prevRow.ACCEPT_PART_NO && prevRow.ITEM_QTY && prevRow.UNIT_PRICE_B) ? true : false;
    }

    if (valid) {
      this.CreateDetailRow(tblIndex);
    }

    return valid;
  }

  CreateDetailRow(tblIndex) {
    let currentMaxRow: number = this.TableData.length || 0;
    let nextMaxRow: number = (Math.floor(currentMaxRow / 10) + 1) * 10;

    if (currentMaxRow - tblIndex <= 2) {
      for (let i = currentMaxRow; i < nextMaxRow; i++) {
        this.TableData.push({
          INVOICE_PROCESS: 'N'
        });
      }

      this.TableData = this.TableData.slice();
    }

  }

  DeleteRow(index) {
    this.modal.confirm("Are you sure to remove this row?", this.viewref
      , () => {
        this.TableData.splice(index, 1);
        this.TableData = [...this.TableData];
        //this.ExpenseChanged()
      }, () => { })
  }

  CheckPO(event: any, elemID: string, partNo: string, index: number, data: any) {
    let currentElement = this.el.nativeElement.querySelector("#" + elemID);

    this.http.get("AC", "SNPE036_CheckPOByPartNo", this.VendorCode, this.InvoiceNo, partNo)
      .subscribe(result => {
        this.MatchedPO = result.Table;

        if (this.MatchedPO.length === 1) {
          this.SetPOMatchOne(data, index, this.MatchedPO[0], currentElement);
        } else if (this.MatchedPO.length > 1) {
          // this.SetPOMatchMore
          this.MatchedPO.forEach(d => d.CHECK = this.CheckIfExists(d));
          this.dialog.OpenDialog();
        } else {
          data.ACCEPT_PART_NO = null;
          currentElement.focus();
          this.modal.error("Unable to find matched PO.", this.viewref);
        }

        // this.TableData = this.TableData.slice();

      }, err => {
        this.modal.error(err.message, this.viewref);
      })
  }

  AcceptSelectedPO() {
    let thisPartNo = this.MatchedPO[0].ACCEPT_PART_NO;

    //Remove exists PO
    while (this.TableData.find(d => d.ACCEPT_PART_NO === thisPartNo)) {
      let index = this.TableData.findIndex(d => d.ACCEPT_PART_NO === thisPartNo);

      this.TableData.splice(index, 1);
    }

    let ActiveRow = this.TableData.filter((d, i) => this.CheckRequiredFields(i, false));
    let SelectedRow = this.MatchedPO.filter(d => d.CHECK)
    console.log('s', SelectedRow)
    SelectedRow = SelectedRow.map(d => {
      return {
        // CHECK: true,
        ACCEPT_PART_NO: d.ACCEPT_PART_NO,
        ORDER_PART_NO: d.ORDER_PART_NO,
        PART_NAME: d.PART_NAME,
        PO_NO: d.PO_NO,
        PO_DATE: d.PO_DATE,
        ITEM_QTY: d.ITEM_QTY,
        UNIT_PRICE_B: d.UNIT_PRICE_B,
        AMOUNT: d.AMOUNT,
        ORDER_QTY: d.ORDER_QTY,
        ITEM_NO: d.ITEM_NO,
        SUB_ITEM_NO: d.SUB_ITEM_NO,
        INVOICE_PROCESS: 'N',
        DUTY_RATE: d.DUTY_RATE,
        ACCEPT_QTY : d.ACCEPT_QTY
        //INCOME_TAX: this.global.Round((d.UNIT_PRICE_B * d.ITEM_QTY * d.DUTY_RATE) / 100,2),
        //EXCISE: d.EXCISE,
        //INTERIOR: d.INTERIOR,
        //CALCULATE_TYPE: d.CALCULATE_TYPE,
        //EXCISE_RATE: d.EXCISE_RATE,
        //RETAIL_PRICE: d.RETAIL_PRICE,
        //CAPACITY_RATE: d.CAPACITY_RATE
      }
    });

    this.TableData = ActiveRow.concat(SelectedRow)
    //this.ExpenseChanged();

    this.TableData = this.TableData.slice();
    this.dialog.Close();
  }

  
  SetPOMatchOne(data: any, index: number, result: any, currentElement: any) {

    let foundDuplicate = this.TableData.find((d, i) => {
      return index !== i
        && result.ACCEPT_PART_NO === this.TableData[i].ACCEPT_PART_NO
        && result.PO_NO === this.TableData[i].PO_NO
        && result.ITEM_NO === this.TableData[i].ITEM_NO
        && result.SUB_ITEM_NO === this.TableData[i].SUB_ITEM_NO
    })

    if (foundDuplicate) {
      data.ACCEPT_PART_NO = null;
      currentElement.focus();
      this.modal.error("Unable to insert duplicated record.", this.viewref);
      return;
    }

    // data.CHECK = true;
    data.ACCEPT_PART_NO = result.ACCEPT_PART_NO;
    data.ORDER_PART_NO = result.ORDER_PART_NO;
    data.PART_NAME = result.PART_NAME;
    data.PO_NO = result.PO_NO;
    data.PO_DATE = result.PO_DATE;
    data.ITEM_QTY = result.ITEM_QTY;
    data.UNIT_PRICE_B = result.UNIT_PRICE_B;
    data.AMOUNT = result.AMOUNT;
    data.ORDER_QTY = result.ORDER_QTY;
    data.ACCEPT_QTY = result.ACCEPT_QTY;
    data.ITEM_NO = result.ITEM_NO;
    data.SUB_ITEM_NO = result.SUB_ITEM_NO;
    data.INVOICE_PROCESS = 'N';
    data.DUTY_RATE = result.DUTY_RATE;
   // data.INCOME_TAX = this.global.Round(data.UNIT_PRICE_B * data.ITEM_QTY * (data.DUTY_RATE / 100),2)
    //data.EXCISE = result.EXCISE
    //data.INTERIOR = result.INTERIOR
    //data.CALCULATE_TYPE = result.CALCULATE_TYPE
    //data.EXCISE_RATE = result.EXCISE_RATE
    //data.RETAIL_PRICE = result.RETAIL_PRICE
    //data.CAPACITY_RATE = result.CAPACITY_RATE
    //this.ExpenseChanged();
  }

  SetVendorCodeLookup(value) {
    if (value.VENDOR_CODE) {
      this.Vendor = value.LOOKUP_VENDOR_NAME;
      this.VendorCode = value.VENDOR_CODE;

    } else {
      this.Vendor = null;
      this.VendorCode = null;
      this.el.nativeElement.querySelector("#vendorcode").focus();
      this.modal.error("Unable to find vendor.", this.viewref);
    }
  }

  // CheckboxChange(evt, data, index) {
  //   if (!evt.checked) {
  //     this.modal.confirm("Would you like to delete this row?", this.viewref
  //       , () => {
  //         this.TableData.splice(index, 1);

  //         this.TableData = this.TableData.slice();
  //       }, () => {
  //         data.CHECK = true;

  //         this.TableData = this.TableData.slice();
  //       })
  //   }
  // }

  CheckIfExists(data) {
    return this.TableData.find(d => {
      return d.ACCEPT_PART_NO === data.ACCEPT_PART_NO
        && d.PO_NO === data.PO_NO
        && d.ITEM_NO === data.ITEM_NO
        && d.SUB_ITEM_NO === data.SUB_ITEM_NO
    })
  }

  SetNewPartNo(part: any, data: any) {
    this.tempData.Part = part;
    data.ACCEPT_PART_NO = part.PART_NO;
  }

  CancelPartNo(data: any) {
    data.ACCEPT_PART_NO = this.tempData.Part.PART_NO;
  }

  TotalQty() {
    return this.TableData.reduce((a, b) => a + (b.ITEM_QTY || 0), 0);
  }

  TotalPrice() {
    return this.TableData.reduce((a, b) => a + ((b.ITEM_QTY || 0) * (b.UNIT_PRICE_B || 0))
      , 0);
  }

  

  QtyChange(data) {

    if (data.ITEM_QTY > data.ACCEPT_QTY) {
      data.ITEM_QTY = data.ACCEPT_QTY
    }

    // if (data.CALCULATE_TYPE == 'Capacity') {
    //   data.EXCISE = data.CAPACITY_RATE * (data.CAPACITY * data.ITEM_QTY);
    // } else {
    //   data.EXCISE = (data.EXCISE_RATE / 100) * data.RETAIL_PRICE * data.ITEM_QTY;
    // }

    // data.INCOME_TAX = this.global.Round((data.UNIT_PRICE_B * data.ITEM_QTY * data.DUTY_RATE) / 100,2);
    // data.INTERIOR = data.EXCISE / 10;
    //data.ITEM_QTY > data.ORDER_QTY ? data.ORDER_QTY : data.ITEM_QTY;
  }



  BackToGrid() {
    this.ShowList = true;
    this.IsCancel = false;
  }
}
